#nullable enable
using Canon.Core.Abstractions;
using Canon.Core.GrammarParser;
using Canon.Core.Enums;
namespace Canon.Console.Services;

public class GeneratedTransformer : ITransformer
{
    private IDictionary<TerminatorBase, string> _shiftPointers;

    public string Name { get; }

    public IDictionary<Terminator, ReduceInformation> ReduceTable { get; }

    public IDictionary<TerminatorBase, ITransformer> ShiftTable { get; }

    public GeneratedTransformer(Dictionary<TerminatorBase, string> shiftTable,
        Dictionary<Terminator, ReduceInformation> reduceTable, string name)
    {
        ReduceTable = reduceTable;
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = shiftTable;
        Name = name;
    }

    public GeneratedTransformer()
    {
        ReduceTable = new Dictionary<Terminator, ReduceInformation>();
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = new Dictionary<TerminatorBase, string>();
        Name = Guid.NewGuid().ToString();
    }

    public void ConstructShiftTable(Dictionary<string, GeneratedTransformer> transformers)
    {
        foreach (KeyValuePair<TerminatorBase,string> pair in _shiftPointers)
        {
            ShiftTable.Add(pair.Key, transformers[pair.Value]);
        }
    }

    public override bool Equals(object? obj)
    {
        if (obj is not GeneratedTransformer other)
        {
            return false;
        }

        return Name == other.Name;
    }

    public override int GetHashCode() => Name.GetHashCode();
}
public class GeneratedGrammarParser : IGrammarParser
{
	private static readonly Dictionary<string, GeneratedTransformer> s_transformers = new()
	{
		{ "90611b1a-2bce-4802-bf73-921489b4be5a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramStruct), "6be8c03f-a355-4fad-b232-4ac88c518577"}, { new NonTerminator(NonTerminatorType.ProgramHead), "50607043-8a34-45f9-abb6-9ce02660d80e"}, { new Terminator(KeywordType.Program), "3d957beb-2526-437d-905c-ff4aac1228c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "90611b1a-2bce-4802-bf73-921489b4be5a") },
		{ "6be8c03f-a355-4fad-b232-4ac88c518577", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.StartNonTerminator))}, }, "6be8c03f-a355-4fad-b232-4ac88c518577") },
		{ "50607043-8a34-45f9-abb6-9ce02660d80e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "e00f3ef2-1336-41d2-a155-e0bb8c8dec47"},}, new Dictionary<Terminator, ReduceInformation>{ }, "50607043-8a34-45f9-abb6-9ce02660d80e") },
		{ "3d957beb-2526-437d-905c-ff4aac1228c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "7cec190a-2432-4b18-9a39-fd3c8a3bc0c6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3d957beb-2526-437d-905c-ff4aac1228c7") },
		{ "e00f3ef2-1336-41d2-a155-e0bb8c8dec47", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramBody), "46c87e04-af93-429e-bfc5-6b948ad82cba"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "a37aaf60-3b03-4a2c-b031-116da8e63e77"}, { new Terminator(KeywordType.Const), "8126a781-8bd8-4d56-aec5-7dc524eace28"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "e00f3ef2-1336-41d2-a155-e0bb8c8dec47") },
		{ "7cec190a-2432-4b18-9a39-fd3c8a3bc0c6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "d6f9c3aa-36c9-43a0-b565-0db933dd564c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "7cec190a-2432-4b18-9a39-fd3c8a3bc0c6") },
		{ "46c87e04-af93-429e-bfc5-6b948ad82cba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Period), "06db7283-d00c-46a9-92b1-72159776d643"},}, new Dictionary<Terminator, ReduceInformation>{ }, "46c87e04-af93-429e-bfc5-6b948ad82cba") },
		{ "a37aaf60-3b03-4a2c-b031-116da8e63e77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "dfad2b5d-d6dd-402e-a38d-4f218be5055c"}, { new Terminator(KeywordType.Var), "cd5fd0ce-d67f-4c63-b18c-d85c2aed6516"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "a37aaf60-3b03-4a2c-b031-116da8e63e77") },
		{ "8126a781-8bd8-4d56-aec5-7dc524eace28", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstDeclaration), "828705d0-e9e0-42b1-9a68-5f6d1a6f7244"}, { Terminator.IdentifierTerminator, "cfa3eddb-b879-495a-888c-a15e593a83de"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8126a781-8bd8-4d56-aec5-7dc524eace28") },
		{ "d6f9c3aa-36c9-43a0-b565-0db933dd564c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "7a396ddc-0e4e-4b99-993a-4456e49c2a0c"}, { Terminator.IdentifierTerminator, "2ca04cb7-9ef9-4c74-938e-f2f02d9f8081"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d6f9c3aa-36c9-43a0-b565-0db933dd564c") },
		{ "06db7283-d00c-46a9-92b1-72159776d643", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramStruct))}, }, "06db7283-d00c-46a9-92b1-72159776d643") },
		{ "dfad2b5d-d6dd-402e-a38d-4f218be5055c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramDeclarations), "7d4e8132-5e7a-443a-b07d-788ba8841721"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "dfad2b5d-d6dd-402e-a38d-4f218be5055c") },
		{ "cd5fd0ce-d67f-4c63-b18c-d85c2aed6516", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclaration), "73478f18-c844-416d-83a8-b1c5f2e01a44"}, { new NonTerminator(NonTerminatorType.IdentifierList), "3ad3df67-5b8e-4f8b-b8fa-02f49a07974f"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cd5fd0ce-d67f-4c63-b18c-d85c2aed6516") },
		{ "828705d0-e9e0-42b1-9a68-5f6d1a6f7244", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "9a324ab4-c38c-48f2-b876-da77ce734741"},}, new Dictionary<Terminator, ReduceInformation>{ }, "828705d0-e9e0-42b1-9a68-5f6d1a6f7244") },
		{ "cfa3eddb-b879-495a-888c-a15e593a83de", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "e1c5f38e-9775-4f46-9752-0245bd26c319"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cfa3eddb-b879-495a-888c-a15e593a83de") },
		{ "7a396ddc-0e4e-4b99-993a-4456e49c2a0c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "88c4eeba-96b5-4406-a268-28143fc11b91"}, { new Terminator(DelimiterType.Comma), "a224ba55-a1c8-44cb-921f-0b22f63a8720"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7a396ddc-0e4e-4b99-993a-4456e49c2a0c") },
		{ "2ca04cb7-9ef9-4c74-938e-f2f02d9f8081", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "2ca04cb7-9ef9-4c74-938e-f2f02d9f8081") },
		{ "7d4e8132-5e7a-443a-b07d-788ba8841721", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "ded17b85-4f75-4f12-83c0-7251b61b0575"}, { new Terminator(KeywordType.Begin), "cf0fb073-670e-41ef-9ba0-f3574263f83c"}, { new NonTerminator(NonTerminatorType.Subprogram), "6720686e-c18d-42db-886d-0ea15a025e4e"}, { new NonTerminator(NonTerminatorType.SubprogramHead), "ec009498-d7cb-4a74-bf2b-fe58c33a939b"}, { new Terminator(KeywordType.Procedure), "74e4a795-28da-4e76-bc1e-df2d8dd0d469"}, { new Terminator(KeywordType.Function), "d79bb6b4-0d63-426e-bbe1-337bf2ea0331"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7d4e8132-5e7a-443a-b07d-788ba8841721") },
		{ "73478f18-c844-416d-83a8-b1c5f2e01a44", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "9d062b29-5a3c-487a-9aff-2c7b68f5dddd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "73478f18-c844-416d-83a8-b1c5f2e01a44") },
		{ "3ad3df67-5b8e-4f8b-b8fa-02f49a07974f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "e3cbbc60-cd76-475b-8563-5cb7910dc73e"}, { new Terminator(DelimiterType.Comma), "8f8c7ec2-f815-4e9d-a81c-75a35dd98773"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3ad3df67-5b8e-4f8b-b8fa-02f49a07974f") },
		{ "c5b02395-6a16-42ea-b32a-eb56cf6039ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "c5b02395-6a16-42ea-b32a-eb56cf6039ee") },
		{ "9a324ab4-c38c-48f2-b876-da77ce734741", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "f6d55570-682a-478f-8c35-7f80be5ee590"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "9a324ab4-c38c-48f2-b876-da77ce734741") },
		{ "e1c5f38e-9775-4f46-9752-0245bd26c319", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "f511e9af-2608-420a-95ca-4229f7e0221d"}, { new Terminator(OperatorType.Plus), "325cf5df-ceeb-4714-9a59-609e0c70f5ec"}, { new Terminator(OperatorType.Minus), "c677ac55-ad97-463f-a5f7-fd780dd8c6c4"}, { Terminator.NumberTerminator, "901a4fc6-d7b1-4270-ba99-0270931d821a"}, { Terminator.CharacterTerminator, "fd059355-14ca-4c3a-b2b6-433d81782f6f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e1c5f38e-9775-4f46-9752-0245bd26c319") },
		{ "88c4eeba-96b5-4406-a268-28143fc11b91", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "88c4eeba-96b5-4406-a268-28143fc11b91") },
		{ "a224ba55-a1c8-44cb-921f-0b22f63a8720", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "5d19b81a-25de-4dba-a3b2-906d1fe4be7f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a224ba55-a1c8-44cb-921f-0b22f63a8720") },
		{ "ded17b85-4f75-4f12-83c0-7251b61b0575", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramBody))}, }, "ded17b85-4f75-4f12-83c0-7251b61b0575") },
		{ "cf0fb073-670e-41ef-9ba0-f3574263f83c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "16a69e4e-245c-4274-95eb-b8a455a844c0"}, { new NonTerminator(NonTerminatorType.Statement), "7ec830cd-22ff-4a49-ad34-2c6648ddd368"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "cf0fb073-670e-41ef-9ba0-f3574263f83c") },
		{ "6720686e-c18d-42db-886d-0ea15a025e4e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "e31b7a9c-5115-47a1-9d6a-53eb4adbc5f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6720686e-c18d-42db-886d-0ea15a025e4e") },
		{ "ec009498-d7cb-4a74-bf2b-fe58c33a939b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "6bc7265d-8f24-40dd-a2f8-374b5add33ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ec009498-d7cb-4a74-bf2b-fe58c33a939b") },
		{ "74e4a795-28da-4e76-bc1e-df2d8dd0d469", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "8cf97192-1d35-4d8c-8133-447952742fc0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "74e4a795-28da-4e76-bc1e-df2d8dd0d469") },
		{ "d79bb6b4-0d63-426e-bbe1-337bf2ea0331", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "5c8f1189-0625-450c-9468-bf65664a0b98"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d79bb6b4-0d63-426e-bbe1-337bf2ea0331") },
		{ "9d062b29-5a3c-487a-9aff-2c7b68f5dddd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "11d34202-306d-49bd-949b-40294e9d988f"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "9d062b29-5a3c-487a-9aff-2c7b68f5dddd") },
		{ "e3cbbc60-cd76-475b-8563-5cb7910dc73e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "07e663cb-1741-49db-9287-cf1fd3f7d031"}, { new NonTerminator(NonTerminatorType.BasicType), "86ffd448-1ced-4f55-ae5c-0cce2ea6fd67"}, { new Terminator(KeywordType.Array), "b6c5ee15-27d5-4b60-8599-fb38f382e3ae"}, { new Terminator(KeywordType.Integer), "ed80790b-88ef-4371-b0e7-81e94e5fac45"}, { new Terminator(KeywordType.Real), "7388243b-8ed7-4285-8409-382eea2bf0ac"}, { new Terminator(KeywordType.Boolean), "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346"}, { new Terminator(KeywordType.Character), "84689f95-8766-49ca-bbc4-f5cb0b102e39"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e3cbbc60-cd76-475b-8563-5cb7910dc73e") },
		{ "8f8c7ec2-f815-4e9d-a81c-75a35dd98773", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "c686f6c5-a093-4cf6-af71-228d5c95931a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8f8c7ec2-f815-4e9d-a81c-75a35dd98773") },
		{ "f6d55570-682a-478f-8c35-7f80be5ee590", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "4827a01a-055a-4429-9483-010a027a695d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f6d55570-682a-478f-8c35-7f80be5ee590") },
		{ "f511e9af-2608-420a-95ca-4229f7e0221d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "f511e9af-2608-420a-95ca-4229f7e0221d") },
		{ "325cf5df-ceeb-4714-9a59-609e0c70f5ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "9cc6eb66-2d6c-46b1-89c4-da347ddc59a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "325cf5df-ceeb-4714-9a59-609e0c70f5ec") },
		{ "c677ac55-ad97-463f-a5f7-fd780dd8c6c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "1d0afc81-54fe-4e3d-88d3-de5fbf47196c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c677ac55-ad97-463f-a5f7-fd780dd8c6c4") },
		{ "901a4fc6-d7b1-4270-ba99-0270931d821a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ConstValue))}, }, "901a4fc6-d7b1-4270-ba99-0270931d821a") },
		{ "fd059355-14ca-4c3a-b2b6-433d81782f6f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ConstValue))}, }, "fd059355-14ca-4c3a-b2b6-433d81782f6f") },
		{ "5d19b81a-25de-4dba-a3b2-906d1fe4be7f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "5d19b81a-25de-4dba-a3b2-906d1fe4be7f") },
		{ "16a69e4e-245c-4274-95eb-b8a455a844c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "ce745382-21ef-442e-b9c6-76b08750a304"}, { new Terminator(DelimiterType.Semicolon), "6539c4c8-777a-4559-bee6-f6d854880735"},}, new Dictionary<Terminator, ReduceInformation>{ }, "16a69e4e-245c-4274-95eb-b8a455a844c0") },
		{ "7ec830cd-22ff-4a49-ad34-2c6648ddd368", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, }, "7ec830cd-22ff-4a49-ad34-2c6648ddd368") },
		{ "0917a51c-0f6b-4995-9b71-a70bfae21876", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "28d647c9-8b2f-4fed-92f3-08082abc67ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0917a51c-0f6b-4995-9b71-a70bfae21876") },
		{ "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "5ee1ae03-547a-448c-a32d-4dd063ac8436"}, { new NonTerminator(NonTerminatorType.IdVarPart), "965e64cf-6440-47a2-849e-2868c33658a1"}, { new Terminator(DelimiterType.LeftSquareBracket), "e550324e-63e6-47ef-be0f-4c83c10933c8"}, { new Terminator(DelimiterType.LeftParenthesis), "bd4bcb7b-223a-4ee5-9101-adb2f7091bfd"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0") },
		{ "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a") },
		{ "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc") },
		{ "4ced18e3-005a-425d-93ff-95f555f6c0b0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "a2529961-57ff-46eb-b15b-530d1bf858c7"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "50b109dd-887c-4c05-8dcd-aeb93f1123e4"}, { new NonTerminator(NonTerminatorType.Term), "97581c2e-d208-4adc-9fab-ade5a2117761"}, { new NonTerminator(NonTerminatorType.Factor), "9276cbd1-6198-4aeb-84f6-b6fc682d0742"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4ced18e3-005a-425d-93ff-95f555f6c0b0") },
		{ "06bd10fc-30bb-44eb-aa64-356c9ce074ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "6188362c-562c-4105-b854-454880bae64a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "06bd10fc-30bb-44eb-aa64-356c9ce074ee") },
		{ "2718db4f-527a-418c-9c29-cc188ac8ff73", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "16e478c8-6f2f-4184-8b55-aa53cb28a42f"}, { new NonTerminator(NonTerminatorType.Statement), "7ec830cd-22ff-4a49-ad34-2c6648ddd368"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "2718db4f-527a-418c-9c29-cc188ac8ff73") },
		{ "e31b7a9c-5115-47a1-9d6a-53eb4adbc5f1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "e31b7a9c-5115-47a1-9d6a-53eb4adbc5f1") },
		{ "6bc7265d-8f24-40dd-a2f8-374b5add33ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramBody), "f21fab16-071e-4eeb-b728-32bf0f091873"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "0f7f50f5-b9f1-43ee-b07b-ba82140439dd"}, { new Terminator(KeywordType.Const), "74958f5d-76db-4639-9129-124910f851a6"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "6bc7265d-8f24-40dd-a2f8-374b5add33ff") },
		{ "8cf97192-1d35-4d8c-8133-447952742fc0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "2cd2216b-310b-4413-89ea-098fc3a1d1ff"}, { new Terminator(DelimiterType.LeftParenthesis), "d9b56418-af5c-4c92-8227-99611aaab5de"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "8cf97192-1d35-4d8c-8133-447952742fc0") },
		{ "5c8f1189-0625-450c-9468-bf65664a0b98", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "4869b016-0bac-40f3-adae-a3a111c74d78"}, { new Terminator(DelimiterType.LeftParenthesis), "14a16101-1ee0-4169-bc2c-68c26d291bb2"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "5c8f1189-0625-450c-9468-bf65664a0b98") },
		{ "11d34202-306d-49bd-949b-40294e9d988f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "9ee48dbd-6884-476e-9b77-fb8be644b10d"}, { new Terminator(DelimiterType.Comma), "8f8c7ec2-f815-4e9d-a81c-75a35dd98773"},}, new Dictionary<Terminator, ReduceInformation>{ }, "11d34202-306d-49bd-949b-40294e9d988f") },
		{ "07e663cb-1741-49db-9287-cf1fd3f7d031", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "07e663cb-1741-49db-9287-cf1fd3f7d031") },
		{ "86ffd448-1ced-4f55-ae5c-0cce2ea6fd67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Type))}, }, "86ffd448-1ced-4f55-ae5c-0cce2ea6fd67") },
		{ "b6c5ee15-27d5-4b60-8599-fb38f382e3ae", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftSquareBracket), "9c99f02f-b909-4b55-a8f6-e276b54ae8ec"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b6c5ee15-27d5-4b60-8599-fb38f382e3ae") },
		{ "ed80790b-88ef-4371-b0e7-81e94e5fac45", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "ed80790b-88ef-4371-b0e7-81e94e5fac45") },
		{ "7388243b-8ed7-4285-8409-382eea2bf0ac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "7388243b-8ed7-4285-8409-382eea2bf0ac") },
		{ "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346") },
		{ "84689f95-8766-49ca-bbc4-f5cb0b102e39", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "84689f95-8766-49ca-bbc4-f5cb0b102e39") },
		{ "c686f6c5-a093-4cf6-af71-228d5c95931a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "c686f6c5-a093-4cf6-af71-228d5c95931a") },
		{ "4827a01a-055a-4429-9483-010a027a695d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "d7577a94-6ad3-4bd3-a9da-9dca78bd2a2e"}, { new Terminator(OperatorType.Plus), "325cf5df-ceeb-4714-9a59-609e0c70f5ec"}, { new Terminator(OperatorType.Minus), "c677ac55-ad97-463f-a5f7-fd780dd8c6c4"}, { Terminator.NumberTerminator, "901a4fc6-d7b1-4270-ba99-0270931d821a"}, { Terminator.CharacterTerminator, "fd059355-14ca-4c3a-b2b6-433d81782f6f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4827a01a-055a-4429-9483-010a027a695d") },
		{ "9cc6eb66-2d6c-46b1-89c4-da347ddc59a6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "9cc6eb66-2d6c-46b1-89c4-da347ddc59a6") },
		{ "1d0afc81-54fe-4e3d-88d3-de5fbf47196c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "1d0afc81-54fe-4e3d-88d3-de5fbf47196c") },
		{ "ce745382-21ef-442e-b9c6-76b08750a304", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "ce745382-21ef-442e-b9c6-76b08750a304") },
		{ "6539c4c8-777a-4559-bee6-f6d854880735", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "db28850c-320c-46d6-9d6e-3ff20118f291"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "6539c4c8-777a-4559-bee6-f6d854880735") },
		{ "28d647c9-8b2f-4fed-92f3-08082abc67ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "6ee074ba-4fa8-44c8-9081-ae14431e45d2"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "619e203f-159d-4f1c-868e-36b4f560b847"}, { new NonTerminator(NonTerminatorType.Term), "fbcde07f-eb4d-47b6-b018-c813066d4d75"}, { new NonTerminator(NonTerminatorType.Factor), "84a646ba-32b8-4e33-ab78-6bff90f8a404"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "28d647c9-8b2f-4fed-92f3-08082abc67ff") },
		{ "5ee1ae03-547a-448c-a32d-4dd063ac8436", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "8cde9266-21eb-463c-8d62-f8d1cdfe3091"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "619e203f-159d-4f1c-868e-36b4f560b847"}, { new NonTerminator(NonTerminatorType.Term), "fbcde07f-eb4d-47b6-b018-c813066d4d75"}, { new NonTerminator(NonTerminatorType.Factor), "84a646ba-32b8-4e33-ab78-6bff90f8a404"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5ee1ae03-547a-448c-a32d-4dd063ac8436") },
		{ "965e64cf-6440-47a2-849e-2868c33658a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "965e64cf-6440-47a2-849e-2868c33658a1") },
		{ "e550324e-63e6-47ef-be0f-4c83c10933c8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "6b23c687-5d0f-4aa3-b469-d74953965eba"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e550324e-63e6-47ef-be0f-4c83c10933c8") },
		{ "bd4bcb7b-223a-4ee5-9101-adb2f7091bfd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "9dee67d8-2aab-4c02-a675-e43cc4ec147e"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bd4bcb7b-223a-4ee5-9101-adb2f7091bfd") },
		{ "a2529961-57ff-46eb-b15b-530d1bf858c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "6899845a-b146-4818-ae33-c56fa3c9d75d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a2529961-57ff-46eb-b15b-530d1bf858c7") },
		{ "50b109dd-887c-4c05-8dcd-aeb93f1123e4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "cc78b9cf-0c32-4b9c-8f29-3276c7523fe2"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "9a38c895-99d2-4b15-9084-4d27803fd3d9"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "50b109dd-887c-4c05-8dcd-aeb93f1123e4") },
		{ "97581c2e-d208-4adc-9fab-ade5a2117761", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "5006ef3a-a58f-4d87-bfab-6dbff29db55f"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "97581c2e-d208-4adc-9fab-ade5a2117761") },
		{ "9276cbd1-6198-4aeb-84f6-b6fc682d0742", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "9276cbd1-6198-4aeb-84f6-b6fc682d0742") },
		{ "93b819b9-1ca7-4290-97c5-59e1a3cb43f3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3") },
		{ "201eceee-4e28-4853-b659-2d8d88b432d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "201eceee-4e28-4853-b659-2d8d88b432d7") },
		{ "3ef73351-4928-4749-86ef-5788bf2a6588", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "ae758e7d-a9fb-4ef2-a555-87c66fa5d48a"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3ef73351-4928-4749-86ef-5788bf2a6588") },
		{ "5a702cad-386e-49ee-aeb0-2b499a1c6d06", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "a9033df0-172c-406b-9676-88e3991f4ac2"}, { new NonTerminator(NonTerminatorType.IdVarPart), "01f91c61-a2f3-4604-96f9-d16a2b5a61e2"}, { new Terminator(DelimiterType.LeftSquareBracket), "34c7163b-37de-471d-8d79-403b9e3b5dc6"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "5a702cad-386e-49ee-aeb0-2b499a1c6d06") },
		{ "86f108c6-0588-4301-998d-85cb15b55fb1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "9457c3fe-2b83-4ff8-a881-8cb38a00620a"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "86f108c6-0588-4301-998d-85cb15b55fb1") },
		{ "d4bff7f5-6548-4552-8615-16b1d197f9ae", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3d3e8e9b-b8d8-462b-ae2f-dc9c2fcd5453"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d4bff7f5-6548-4552-8615-16b1d197f9ae") },
		{ "6188362c-562c-4105-b854-454880bae64a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "54e1784e-d187-4184-9c51-5497f3b0d0eb"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6188362c-562c-4105-b854-454880bae64a") },
		{ "16e478c8-6f2f-4184-8b55-aa53cb28a42f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "ffdaf087-bb81-4dc5-b07c-b42529c6a7b4"}, { new Terminator(DelimiterType.Semicolon), "6539c4c8-777a-4559-bee6-f6d854880735"},}, new Dictionary<Terminator, ReduceInformation>{ }, "16e478c8-6f2f-4184-8b55-aa53cb28a42f") },
		{ "f21fab16-071e-4eeb-b728-32bf0f091873", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Subprogram))}, }, "f21fab16-071e-4eeb-b728-32bf0f091873") },
		{ "0f7f50f5-b9f1-43ee-b07b-ba82140439dd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "018af930-9833-4c09-96db-7181bc3ee0bf"}, { new Terminator(KeywordType.Var), "08c8b919-8b5e-4147-980b-1e7a7cc040c3"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "0f7f50f5-b9f1-43ee-b07b-ba82140439dd") },
		{ "74958f5d-76db-4639-9129-124910f851a6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstDeclaration), "e372c27d-cca1-418b-8bea-ce178748ad62"}, { Terminator.IdentifierTerminator, "cfa3eddb-b879-495a-888c-a15e593a83de"},}, new Dictionary<Terminator, ReduceInformation>{ }, "74958f5d-76db-4639-9129-124910f851a6") },
		{ "2cd2216b-310b-4413-89ea-098fc3a1d1ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "2cd2216b-310b-4413-89ea-098fc3a1d1ff") },
		{ "d9b56418-af5c-4c92-8227-99611aaab5de", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "6888e160-c100-44c5-9d68-e7023478f941"}, { new NonTerminator(NonTerminatorType.Parameter), "8b0b00b8-c4dc-402f-899c-a7cc29dbd171"}, { new NonTerminator(NonTerminatorType.VarParameter), "6a7f478b-7211-41a2-b7d5-b6526056fbc2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "5111c4a1-3ed8-496b-9cb6-2371c39683f5"}, { new Terminator(KeywordType.Var), "e28a067a-3740-40f5-b3c8-4fea7d514add"}, { new NonTerminator(NonTerminatorType.IdentifierList), "37a29538-98f5-4309-93af-5b6825ab5170"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d9b56418-af5c-4c92-8227-99611aaab5de") },
		{ "4869b016-0bac-40f3-adae-a3a111c74d78", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "4551fd3e-0602-4903-9e62-5bc95c51def2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4869b016-0bac-40f3-adae-a3a111c74d78") },
		{ "14a16101-1ee0-4169-bc2c-68c26d291bb2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "b1e82fe8-9616-4049-9bf3-225e7f5fb4a0"}, { new NonTerminator(NonTerminatorType.Parameter), "8b0b00b8-c4dc-402f-899c-a7cc29dbd171"}, { new NonTerminator(NonTerminatorType.VarParameter), "6a7f478b-7211-41a2-b7d5-b6526056fbc2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "5111c4a1-3ed8-496b-9cb6-2371c39683f5"}, { new Terminator(KeywordType.Var), "e28a067a-3740-40f5-b3c8-4fea7d514add"}, { new NonTerminator(NonTerminatorType.IdentifierList), "37a29538-98f5-4309-93af-5b6825ab5170"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "14a16101-1ee0-4169-bc2c-68c26d291bb2") },
		{ "9ee48dbd-6884-476e-9b77-fb8be644b10d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "d61399c7-941b-40e8-bedd-a04cacb0a8b0"}, { new NonTerminator(NonTerminatorType.BasicType), "86ffd448-1ced-4f55-ae5c-0cce2ea6fd67"}, { new Terminator(KeywordType.Array), "b6c5ee15-27d5-4b60-8599-fb38f382e3ae"}, { new Terminator(KeywordType.Integer), "ed80790b-88ef-4371-b0e7-81e94e5fac45"}, { new Terminator(KeywordType.Real), "7388243b-8ed7-4285-8409-382eea2bf0ac"}, { new Terminator(KeywordType.Boolean), "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346"}, { new Terminator(KeywordType.Character), "84689f95-8766-49ca-bbc4-f5cb0b102e39"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9ee48dbd-6884-476e-9b77-fb8be644b10d") },
		{ "9c99f02f-b909-4b55-a8f6-e276b54ae8ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Period), "2a923053-f405-441d-a303-6846a1fc0ca4"}, { Terminator.NumberTerminator, "1971081c-4eb1-4c86-996b-7369b868a7aa"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9c99f02f-b909-4b55-a8f6-e276b54ae8ec") },
		{ "d7577a94-6ad3-4bd3-a9da-9dca78bd2a2e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "d7577a94-6ad3-4bd3-a9da-9dca78bd2a2e") },
		{ "db28850c-320c-46d6-9d6e-3ff20118f291", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, }, "db28850c-320c-46d6-9d6e-3ff20118f291") },
		{ "6ee074ba-4fa8-44c8-9081-ae14431e45d2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "6ee074ba-4fa8-44c8-9081-ae14431e45d2") },
		{ "619e203f-159d-4f1c-868e-36b4f560b847", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "72a7c8b5-9daf-463e-891e-8c1010976888"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "cb3d8334-df7a-465c-bf9d-c3e69ccd4c3b"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "619e203f-159d-4f1c-868e-36b4f560b847") },
		{ "fbcde07f-eb4d-47b6-b018-c813066d4d75", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "f54f341f-5053-4d91-a494-d5bacd33fb9d"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "fbcde07f-eb4d-47b6-b018-c813066d4d75") },
		{ "84a646ba-32b8-4e33-ab78-6bff90f8a404", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "84a646ba-32b8-4e33-ab78-6bff90f8a404") },
		{ "d23fe1d4-8542-4cea-bb8b-ad7762c6debb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb") },
		{ "5d4779cd-0879-4c4c-a569-b0f33b676958", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "5d4779cd-0879-4c4c-a569-b0f33b676958") },
		{ "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "78a86961-7bc0-433f-8e8e-100734f9b4d8"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a") },
		{ "55e820e5-353c-47c2-b6b8-939b1a62618e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "d7837f56-0eeb-4ec9-abc0-4b333d86dded"}, { new NonTerminator(NonTerminatorType.IdVarPart), "320bbf1d-85cd-4ec1-9175-a75bb460d26e"}, { new Terminator(DelimiterType.LeftSquareBracket), "6149c95f-dddb-4c4e-b39e-a8aab89b332b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "55e820e5-353c-47c2-b6b8-939b1a62618e") },
		{ "2fe20549-306e-42d8-b61e-95ac9d9388a3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f14ff22f-d36c-482e-a39a-c5306b0e821c"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2fe20549-306e-42d8-b61e-95ac9d9388a3") },
		{ "89086f71-9aef-4de8-b3d4-c0927cd6cdda", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "0d0bd6c0-bafc-4115-8a4f-5b49e4e0c0fc"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "89086f71-9aef-4de8-b3d4-c0927cd6cdda") },
		{ "8cde9266-21eb-463c-8d62-f8d1cdfe3091", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "8cde9266-21eb-463c-8d62-f8d1cdfe3091") },
		{ "6b23c687-5d0f-4aa3-b469-d74953965eba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "21418940-a961-452a-9eec-a5d9757dab29"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6b23c687-5d0f-4aa3-b469-d74953965eba") },
		{ "60377190-18c7-4991-b320-4fd8443987bb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "60377190-18c7-4991-b320-4fd8443987bb") },
		{ "08ecf76a-ceed-46ea-ac03-444efc640a89", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "105e094b-a7b1-4d71-8d24-3ca532152fbd"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "a3494fed-7a61-4eb3-9104-daacbe411d10"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "08ecf76a-ceed-46ea-ac03-444efc640a89") },
		{ "288abaa4-40f6-4d16-b023-96815851dc13", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "4aa8465a-5d02-4525-9106-965aac2e2de8"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "288abaa4-40f6-4d16-b023-96815851dc13") },
		{ "b0107e15-0526-414e-a98f-dfefdb6e55cd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "b0107e15-0526-414e-a98f-dfefdb6e55cd") },
		{ "bf99b129-0c44-445f-880d-bf9e6106cf77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "bf99b129-0c44-445f-880d-bf9e6106cf77") },
		{ "6ecab451-234e-4f30-b34a-444ced34e95f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6ecab451-234e-4f30-b34a-444ced34e95f") },
		{ "973a3492-2749-48fd-b226-4a224615f310", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "05dbbef3-ffb8-4e26-8086-7e80f57dd174"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "973a3492-2749-48fd-b226-4a224615f310") },
		{ "ef53ba15-d58e-42d8-8e7a-496a78662e7e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "f0ba59d4-a058-40d8-be5c-bd126aac17a7"}, { new NonTerminator(NonTerminatorType.IdVarPart), "6713d6de-ac29-4c62-a528-473f2329c575"}, { new Terminator(DelimiterType.LeftSquareBracket), "ac1be363-42ec-4ee0-8361-3f33ae9cd784"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "ef53ba15-d58e-42d8-8e7a-496a78662e7e") },
		{ "30f9f334-028f-4c9e-8fa7-d00e71c02f7a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "20f1c3fe-4af5-4646-b59b-0655a2237002"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "30f9f334-028f-4c9e-8fa7-d00e71c02f7a") },
		{ "43bfef6e-27a6-4ed5-9181-944c0c0869db", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ebb0198c-74d7-4bb3-bb6d-57fdd023a670"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "43bfef6e-27a6-4ed5-9181-944c0c0869db") },
		{ "9dee67d8-2aab-4c02-a675-e43cc4ec147e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "1c6b6f91-4652-44e9-b330-11fdf63c8aca"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9dee67d8-2aab-4c02-a675-e43cc4ec147e") },
		{ "4deb0928-e0b2-46ad-b36d-6db5892538d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "4deb0928-e0b2-46ad-b36d-6db5892538d3") },
		{ "5c8951f9-34e6-4f48-ba21-c9d794f68704", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "46ce6040-4a0c-4de4-9e1c-cb53ddb406c2"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "83c210bd-1b86-4d2a-bbbc-a6fbe151cabe"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "5c8951f9-34e6-4f48-ba21-c9d794f68704") },
		{ "b5dff012-7224-404c-be00-e05d8ecddad8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "47ead8ca-782f-4e56-8a62-5c47c0e006e1"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b5dff012-7224-404c-be00-e05d8ecddad8") },
		{ "cd7425f7-d1ab-4718-9b02-2736198de4ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "cd7425f7-d1ab-4718-9b02-2736198de4ee") },
		{ "82d93635-2453-4516-acc4-24c86c98ac12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "82d93635-2453-4516-acc4-24c86c98ac12") },
		{ "71eda53f-2674-4c70-aa3b-88ba5fe22e84", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "71eda53f-2674-4c70-aa3b-88ba5fe22e84") },
		{ "d54afc8c-616a-4817-8f09-a030d5f9cafc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "c5d39c56-4bdc-40dd-b522-82530e822c3b"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d54afc8c-616a-4817-8f09-a030d5f9cafc") },
		{ "830c5311-98d9-4b2e-bbb8-dc489f2e47a8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "fcab8a5c-9305-469a-8ff0-0508b83b4028"}, { new NonTerminator(NonTerminatorType.IdVarPart), "54eabc52-337d-4da5-ab53-7987c3328419"}, { new Terminator(DelimiterType.LeftSquareBracket), "3a05364c-f1a2-43da-b256-2b5b6f5351e4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8") },
		{ "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f2528da4-57c8-4240-b34e-a9ee566e1396"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446") },
		{ "041ba0db-1aec-4fb5-ab79-e036dc670fc7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "b28cb140-e36a-4c3b-9dce-592df0d8cb5b"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "041ba0db-1aec-4fb5-ab79-e036dc670fc7") },
		{ "6899845a-b146-4818-ae33-c56fa3c9d75d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "8d1ec073-1386-4893-8df6-d4bf45e72d90"}, { new NonTerminator(NonTerminatorType.Variable), "b673a04f-5b49-48ea-b31a-e543bb450990"}, { Terminator.IdentifierTerminator, "a1d8212d-7a8c-487f-af11-a09b7a139999"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "d7769531-8722-4562-a86c-db01e53d2601"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "232955bf-eb89-4b2b-b0b2-2a2def84a012"}, { new Terminator(KeywordType.If), "53bcac81-472d-472c-ac1b-95ccd69eec62"}, { new Terminator(KeywordType.For), "343bc0df-a720-484c-a7ec-c3f13b014a7e"}, { new Terminator(KeywordType.Begin), "b81770c8-69fc-4aea-85f3-fdbd63baa29a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "6899845a-b146-4818-ae33-c56fa3c9d75d") },
		{ "cc78b9cf-0c32-4b9c-8f29-3276c7523fe2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "51a07fbf-aaa4-407b-882b-78bcc45b1bc6"}, { new NonTerminator(NonTerminatorType.Term), "aab66f1d-f590-4deb-ae68-972232abe638"}, { new NonTerminator(NonTerminatorType.Factor), "f8937803-8908-4014-89c9-d3ee30bd9383"}, { Terminator.NumberTerminator, "cd08502e-759b-445f-a92a-c64f7b7044c9"}, { new NonTerminator(NonTerminatorType.Variable), "4007a2b0-c178-4420-ae43-423f035b0406"}, { new Terminator(DelimiterType.LeftParenthesis), "528e0359-f8c8-4ad3-8321-f3e19847d922"}, { Terminator.IdentifierTerminator, "9de280cf-dfc5-4351-babf-dc4706d14f6f"}, { new Terminator(KeywordType.Not), "08a8a27a-93fb-4bf6-9994-5a3d304db0f5"}, { new Terminator(OperatorType.Minus), "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cc78b9cf-0c32-4b9c-8f29-3276c7523fe2") },
		{ "e60f0a44-0071-48cd-9938-5e1f4ebc1750", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "e60f0a44-0071-48cd-9938-5e1f4ebc1750") },
		{ "bff81bfb-5d76-4d37-ac47-0f8131be9179", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "bff81bfb-5d76-4d37-ac47-0f8131be9179") },
		{ "b74c6061-fc5a-421c-b2ba-b08541ad104b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "b74c6061-fc5a-421c-b2ba-b08541ad104b") },
		{ "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3") },
		{ "df1da848-76b4-4f80-8032-2c5f6b51d257", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "df1da848-76b4-4f80-8032-2c5f6b51d257") },
		{ "d41fbe91-c8fc-4777-8ae9-153d60b07a0a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "d41fbe91-c8fc-4777-8ae9-153d60b07a0a") },
		{ "9a38c895-99d2-4b15-9084-4d27803fd3d9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "0542ee3d-264a-4de5-8617-64787e1b347e"}, { new NonTerminator(NonTerminatorType.Factor), "9276cbd1-6198-4aeb-84f6-b6fc682d0742"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9a38c895-99d2-4b15-9084-4d27803fd3d9") },
		{ "e1972b4b-6669-4585-b56e-954352b788bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "e1972b4b-6669-4585-b56e-954352b788bf") },
		{ "4fb07dba-bf26-4347-a306-1bb7ba903590", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "4fb07dba-bf26-4347-a306-1bb7ba903590") },
		{ "0c2471fb-6af7-45bd-8a04-98ada7a266c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "0c2471fb-6af7-45bd-8a04-98ada7a266c7") },
		{ "5006ef3a-a58f-4d87-bfab-6dbff29db55f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2abaf62a-dbe5-4858-8ba6-86d90966607b"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5006ef3a-a58f-4d87-bfab-6dbff29db55f") },
		{ "6920b693-65be-42ae-ac8b-33b45029671c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "6920b693-65be-42ae-ac8b-33b45029671c") },
		{ "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa") },
		{ "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1") },
		{ "38a02d24-b6a3-44ee-8a9c-ee71205f82ed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "38a02d24-b6a3-44ee-8a9c-ee71205f82ed") },
		{ "2882f7ca-a974-4527-a642-468bc3be3037", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "2882f7ca-a974-4527-a642-468bc3be3037") },
		{ "ae758e7d-a9fb-4ef2-a555-87c66fa5d48a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "aaf7fe49-2a54-49de-8c50-bd730da289a4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ae758e7d-a9fb-4ef2-a555-87c66fa5d48a") },
		{ "8b3df006-7bad-45fc-8f6e-37150dd4a845", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "af50d9a2-1dc6-4ddc-b5be-ce67b3bbb174"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "51d510a3-feb9-492b-a5f1-48f65bcf822f"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "8b3df006-7bad-45fc-8f6e-37150dd4a845") },
		{ "1c76a2a5-f5ba-485f-bea3-ee69def688d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d3aae3ac-6a20-4ba8-8b94-ee49cba974c7"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "1c76a2a5-f5ba-485f-bea3-ee69def688d1") },
		{ "f5b4dfe6-b493-4cf7-87f6-90a82667de84", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "f5b4dfe6-b493-4cf7-87f6-90a82667de84") },
		{ "a7a80208-7348-4366-bc61-cac584c9e04a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a7a80208-7348-4366-bc61-cac584c9e04a") },
		{ "5ace0fc6-1154-458f-9dba-28b9f6160ce6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "5ace0fc6-1154-458f-9dba-28b9f6160ce6") },
		{ "94c79094-9186-4861-a631-4dc359b90b39", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "a7e2f5f7-c748-4678-a2d6-12797b8a0ea1"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "94c79094-9186-4861-a631-4dc359b90b39") },
		{ "859c1708-4168-4083-a2de-7e704d473d03", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "439ee144-159d-4d2a-bff1-c3a237e69073"}, { new NonTerminator(NonTerminatorType.IdVarPart), "f73f2f95-f891-42a2-8292-4b41302acf61"}, { new Terminator(DelimiterType.LeftSquareBracket), "11956c5b-bf6e-494b-9d02-33448bf92371"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "859c1708-4168-4083-a2de-7e704d473d03") },
		{ "544263d9-48f5-4069-a3ea-0808185827ea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "358957ca-e596-44da-bff9-d5bdad6f2e7d"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "544263d9-48f5-4069-a3ea-0808185827ea") },
		{ "7492c66c-0393-4775-a03b-65a74bbbaba8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "58a3b620-774c-489d-9682-cddbce9ac5cb"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7492c66c-0393-4775-a03b-65a74bbbaba8") },
		{ "a9033df0-172c-406b-9676-88e3991f4ac2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "25b17c7b-97a8-43ac-a728-5808e639fea0"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a9033df0-172c-406b-9676-88e3991f4ac2") },
		{ "01f91c61-a2f3-4604-96f9-d16a2b5a61e2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "01f91c61-a2f3-4604-96f9-d16a2b5a61e2") },
		{ "34c7163b-37de-471d-8d79-403b9e3b5dc6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2fdfc1a2-08ac-4753-a6f8-2aee755b9245"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34c7163b-37de-471d-8d79-403b9e3b5dc6") },
		{ "9457c3fe-2b83-4ff8-a881-8cb38a00620a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "9457c3fe-2b83-4ff8-a881-8cb38a00620a") },
		{ "3d3e8e9b-b8d8-462b-ae2f-dc9c2fcd5453", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3d3e8e9b-b8d8-462b-ae2f-dc9c2fcd5453") },
		{ "54e1784e-d187-4184-9c51-5497f3b0d0eb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "80d1f620-8bd2-4471-9f13-483d66a4829a"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "3beb4763-a285-450a-a9bd-e1910cbba9b5"}, { new NonTerminator(NonTerminatorType.Term), "4f4146ff-f555-4046-b800-bc3b4bc8c549"}, { new NonTerminator(NonTerminatorType.Factor), "165267cc-114b-433c-b8f4-b069d96d3c59"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "54e1784e-d187-4184-9c51-5497f3b0d0eb") },
		{ "ffdaf087-bb81-4dc5-b07c-b42529c6a7b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "ffdaf087-bb81-4dc5-b07c-b42529c6a7b4") },
		{ "018af930-9833-4c09-96db-7181bc3ee0bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "cc21909e-1e89-434e-a4b9-bfb34e403767"}, { new Terminator(KeywordType.Begin), "d59cd94c-e094-4e60-9a84-d5e6aaf822e4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "018af930-9833-4c09-96db-7181bc3ee0bf") },
		{ "08c8b919-8b5e-4147-980b-1e7a7cc040c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclaration), "618a1642-a494-4a2e-9e62-578cb4da299e"}, { new NonTerminator(NonTerminatorType.IdentifierList), "3ad3df67-5b8e-4f8b-b8fa-02f49a07974f"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "08c8b919-8b5e-4147-980b-1e7a7cc040c3") },
		{ "e372c27d-cca1-418b-8bea-ce178748ad62", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "8c031ee8-d349-4766-97b0-5e522db5e0f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e372c27d-cca1-418b-8bea-ce178748ad62") },
		{ "6888e160-c100-44c5-9d68-e7023478f941", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4de0a628-7067-429e-a2ce-9d57086f2ce5"}, { new Terminator(DelimiterType.Semicolon), "7294f987-5629-4ddb-b781-31be970fa1d7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6888e160-c100-44c5-9d68-e7023478f941") },
		{ "8b0b00b8-c4dc-402f-899c-a7cc29dbd171", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, }, "8b0b00b8-c4dc-402f-899c-a7cc29dbd171") },
		{ "6a7f478b-7211-41a2-b7d5-b6526056fbc2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "6a7f478b-7211-41a2-b7d5-b6526056fbc2") },
		{ "5111c4a1-3ed8-496b-9cb6-2371c39683f5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "5111c4a1-3ed8-496b-9cb6-2371c39683f5") },
		{ "e28a067a-3740-40f5-b3c8-4fea7d514add", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ValueParameter), "11772442-515b-4412-bb63-dd78776982e8"}, { new NonTerminator(NonTerminatorType.IdentifierList), "37a29538-98f5-4309-93af-5b6825ab5170"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e28a067a-3740-40f5-b3c8-4fea7d514add") },
		{ "37a29538-98f5-4309-93af-5b6825ab5170", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "b2474d09-fd52-439a-a9f8-75533980927a"}, { new Terminator(DelimiterType.Comma), "8f8c7ec2-f815-4e9d-a81c-75a35dd98773"},}, new Dictionary<Terminator, ReduceInformation>{ }, "37a29538-98f5-4309-93af-5b6825ab5170") },
		{ "4551fd3e-0602-4903-9e62-5bc95c51def2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "a0b27552-4305-4fb3-b3b8-449fb57524d8"}, { new Terminator(KeywordType.Integer), "ed80790b-88ef-4371-b0e7-81e94e5fac45"}, { new Terminator(KeywordType.Real), "7388243b-8ed7-4285-8409-382eea2bf0ac"}, { new Terminator(KeywordType.Boolean), "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346"}, { new Terminator(KeywordType.Character), "84689f95-8766-49ca-bbc4-f5cb0b102e39"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4551fd3e-0602-4903-9e62-5bc95c51def2") },
		{ "b1e82fe8-9616-4049-9bf3-225e7f5fb4a0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "3bad0549-e2a2-4071-9cc6-8df6540a4ee2"}, { new Terminator(DelimiterType.Semicolon), "7294f987-5629-4ddb-b781-31be970fa1d7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b1e82fe8-9616-4049-9bf3-225e7f5fb4a0") },
		{ "d61399c7-941b-40e8-bedd-a04cacb0a8b0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "d61399c7-941b-40e8-bedd-a04cacb0a8b0") },
		{ "2a923053-f405-441d-a303-6846a1fc0ca4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "6c29e597-515d-4ae8-a580-c3aebb436c9a"}, { new Terminator(DelimiterType.Comma), "471bf78d-2fde-476b-9b02-ae3384db4c60"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2a923053-f405-441d-a303-6846a1fc0ca4") },
		{ "1971081c-4eb1-4c86-996b-7369b868a7aa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "866cb056-9f20-4a70-8167-516a217ddf29"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1971081c-4eb1-4c86-996b-7369b868a7aa") },
		{ "72a7c8b5-9daf-463e-891e-8c1010976888", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "ccd8d5ac-8fc2-42b2-ab38-88c19e66499d"}, { new NonTerminator(NonTerminatorType.Term), "1ada20ce-16e9-499c-9c9b-a8600ec275e3"}, { new NonTerminator(NonTerminatorType.Factor), "29431af9-c5ae-4e4f-abdc-47baee3c6f6b"}, { Terminator.NumberTerminator, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f"}, { new NonTerminator(NonTerminatorType.Variable), "74e351ba-0b8b-42fa-b399-4a9c828d7fdd"}, { new Terminator(DelimiterType.LeftParenthesis), "a6450c5f-91ef-4c82-8f01-8ccfaf647665"}, { Terminator.IdentifierTerminator, "40eb9297-c1b8-43cc-9149-c423265fa2c3"}, { new Terminator(KeywordType.Not), "eefe5be5-e860-47cb-9b8f-4664ee083437"}, { new Terminator(OperatorType.Minus), "67d72f7a-4404-4307-97fa-8e0f58cd710c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "72a7c8b5-9daf-463e-891e-8c1010976888") },
		{ "cb3d8334-df7a-465c-bf9d-c3e69ccd4c3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "2dcef809-d116-4bf0-9699-04f6ec74e270"}, { new NonTerminator(NonTerminatorType.Factor), "84a646ba-32b8-4e33-ab78-6bff90f8a404"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cb3d8334-df7a-465c-bf9d-c3e69ccd4c3b") },
		{ "f54f341f-5053-4d91-a494-d5bacd33fb9d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "74ddf822-e89f-482c-a292-44ca7132751e"}, { Terminator.NumberTerminator, "d23fe1d4-8542-4cea-bb8b-ad7762c6debb"}, { new NonTerminator(NonTerminatorType.Variable), "5d4779cd-0879-4c4c-a569-b0f33b676958"}, { new Terminator(DelimiterType.LeftParenthesis), "c9c8b9f7-5111-4fd5-beb5-d0030e8dc24a"}, { Terminator.IdentifierTerminator, "55e820e5-353c-47c2-b6b8-939b1a62618e"}, { new Terminator(KeywordType.Not), "2fe20549-306e-42d8-b61e-95ac9d9388a3"}, { new Terminator(OperatorType.Minus), "89086f71-9aef-4de8-b3d4-c0927cd6cdda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f54f341f-5053-4d91-a494-d5bacd33fb9d") },
		{ "78a86961-7bc0-433f-8e8e-100734f9b4d8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f0833538-b6f6-4c34-b025-58e7f02aebea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "78a86961-7bc0-433f-8e8e-100734f9b4d8") },
		{ "d7837f56-0eeb-4ec9-abc0-4b333d86dded", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "72942bb3-5c71-4fde-8eae-ed95799366c2"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d7837f56-0eeb-4ec9-abc0-4b333d86dded") },
		{ "320bbf1d-85cd-4ec1-9175-a75bb460d26e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "320bbf1d-85cd-4ec1-9175-a75bb460d26e") },
		{ "6149c95f-dddb-4c4e-b39e-a8aab89b332b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "bddbf2af-982b-4b38-900f-03cd5db89f1e"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6149c95f-dddb-4c4e-b39e-a8aab89b332b") },
		{ "f14ff22f-d36c-482e-a39a-c5306b0e821c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "f14ff22f-d36c-482e-a39a-c5306b0e821c") },
		{ "0d0bd6c0-bafc-4115-8a4f-5b49e4e0c0fc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "0d0bd6c0-bafc-4115-8a4f-5b49e4e0c0fc") },
		{ "21418940-a961-452a-9eec-a5d9757dab29", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "21418940-a961-452a-9eec-a5d9757dab29") },
		{ "5a4cd270-a7b0-4914-ab2a-0e17937d72ce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "ba2b2529-de0a-43f4-a678-53d15e12c7f0"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5a4cd270-a7b0-4914-ab2a-0e17937d72ce") },
		{ "105e094b-a7b1-4d71-8d24-3ca532152fbd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "97b9cc13-a6f5-480a-b43d-d50f75215e83"}, { new NonTerminator(NonTerminatorType.Term), "b7a4825f-4062-4d84-9739-02c01c149bc1"}, { new NonTerminator(NonTerminatorType.Factor), "b96b8ca6-fae8-49d2-9a85-b2261212d529"}, { Terminator.NumberTerminator, "397f05f9-4803-4d37-86b9-ce4ff549f0c8"}, { new NonTerminator(NonTerminatorType.Variable), "fd73f990-083b-4660-abc6-f78979120516"}, { new Terminator(DelimiterType.LeftParenthesis), "54c777e8-bc5d-49e6-ad7c-14a99f440e48"}, { Terminator.IdentifierTerminator, "05968c73-014d-4743-8f5a-78be96d65756"}, { new Terminator(KeywordType.Not), "88fb1eac-0014-40a0-951c-d069fbed21d9"}, { new Terminator(OperatorType.Minus), "b539d14c-42bc-4820-8b06-f05d2358b505"},}, new Dictionary<Terminator, ReduceInformation>{ }, "105e094b-a7b1-4d71-8d24-3ca532152fbd") },
		{ "a3494fed-7a61-4eb3-9104-daacbe411d10", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "3f73623b-19fb-4bea-ae5c-385684a7dd11"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a3494fed-7a61-4eb3-9104-daacbe411d10") },
		{ "4aa8465a-5d02-4525-9106-965aac2e2de8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ef3b5b88-5ef2-49f3-8eb5-f41a0f794e5b"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4aa8465a-5d02-4525-9106-965aac2e2de8") },
		{ "05dbbef3-ffb8-4e26-8086-7e80f57dd174", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a39a2e4b-ba52-4be3-bd28-ebc0359049b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "05dbbef3-ffb8-4e26-8086-7e80f57dd174") },
		{ "f0ba59d4-a058-40d8-be5c-bd126aac17a7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "96d9601f-f194-4f30-a774-e3e06703111a"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f0ba59d4-a058-40d8-be5c-bd126aac17a7") },
		{ "6713d6de-ac29-4c62-a528-473f2329c575", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "6713d6de-ac29-4c62-a528-473f2329c575") },
		{ "ac1be363-42ec-4ee0-8361-3f33ae9cd784", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "678424ee-f442-4b9f-b68f-2cca6e55747a"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ac1be363-42ec-4ee0-8361-3f33ae9cd784") },
		{ "20f1c3fe-4af5-4646-b59b-0655a2237002", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "20f1c3fe-4af5-4646-b59b-0655a2237002") },
		{ "ebb0198c-74d7-4bb3-bb6d-57fdd023a670", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "ebb0198c-74d7-4bb3-bb6d-57fdd023a670") },
		{ "1c6b6f91-4652-44e9-b330-11fdf63c8aca", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "1c6b6f91-4652-44e9-b330-11fdf63c8aca") },
		{ "cf5b6a68-58b4-43b0-88fe-e15516e737be", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "90569cb6-c35a-467a-ba20-6aa7e4cb215d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cf5b6a68-58b4-43b0-88fe-e15516e737be") },
		{ "46ce6040-4a0c-4de4-9e1c-cb53ddb406c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "fd0c3935-1ce8-4297-9736-0847f1f73ffc"}, { new NonTerminator(NonTerminatorType.Term), "dc433b60-bf73-428e-bffd-439333af01e3"}, { new NonTerminator(NonTerminatorType.Factor), "3c3b1067-f688-4177-b4a8-3d532ad969f8"}, { Terminator.NumberTerminator, "6a8eb5f2-a94a-4327-873b-e6ad58275b47"}, { new NonTerminator(NonTerminatorType.Variable), "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee"}, { new Terminator(DelimiterType.LeftParenthesis), "4b46b06f-888d-4c1a-8d7d-5131996ac388"}, { Terminator.IdentifierTerminator, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11"}, { new Terminator(KeywordType.Not), "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2"}, { new Terminator(OperatorType.Minus), "26c11d2c-df29-4059-adab-949a192a3c76"},}, new Dictionary<Terminator, ReduceInformation>{ }, "46ce6040-4a0c-4de4-9e1c-cb53ddb406c2") },
		{ "83c210bd-1b86-4d2a-bbbc-a6fbe151cabe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "ff7b43b3-3ab3-40cd-a9e2-dd6e08e53314"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "83c210bd-1b86-4d2a-bbbc-a6fbe151cabe") },
		{ "47ead8ca-782f-4e56-8a62-5c47c0e006e1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3a49f7dc-9fab-4956-b28f-39573872dd53"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "47ead8ca-782f-4e56-8a62-5c47c0e006e1") },
		{ "c5d39c56-4bdc-40dd-b522-82530e822c3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a34e6d77-a025-4217-bf30-30c698c350f8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c5d39c56-4bdc-40dd-b522-82530e822c3b") },
		{ "fcab8a5c-9305-469a-8ff0-0508b83b4028", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "14642f27-d700-44b3-85b8-d4bc6274a4c2"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fcab8a5c-9305-469a-8ff0-0508b83b4028") },
		{ "54eabc52-337d-4da5-ab53-7987c3328419", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "54eabc52-337d-4da5-ab53-7987c3328419") },
		{ "3a05364c-f1a2-43da-b256-2b5b6f5351e4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2aec9def-baaa-41be-a70e-de9288e7e391"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3a05364c-f1a2-43da-b256-2b5b6f5351e4") },
		{ "f2528da4-57c8-4240-b34e-a9ee566e1396", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "f2528da4-57c8-4240-b34e-a9ee566e1396") },
		{ "b28cb140-e36a-4c3b-9dce-592df0d8cb5b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "b28cb140-e36a-4c3b-9dce-592df0d8cb5b") },
		{ "8d1ec073-1386-4893-8df6-d4bf45e72d90", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "96521b5b-054e-4e01-aec3-30f3a8028d85"}, { new Terminator(KeywordType.Else), "0ce5369e-9dc5-4826-ba82-3ed963f0278c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "8d1ec073-1386-4893-8df6-d4bf45e72d90") },
		{ "b673a04f-5b49-48ea-b31a-e543bb450990", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "c4942b9a-4e6e-4dac-8723-bd97e21b9f51"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b673a04f-5b49-48ea-b31a-e543bb450990") },
		{ "a1d8212d-7a8c-487f-af11-a09b7a139999", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "05003d6c-68bb-4d3f-a153-c110b41aa43c"}, { new NonTerminator(NonTerminatorType.IdVarPart), "965e64cf-6440-47a2-849e-2868c33658a1"}, { new Terminator(DelimiterType.LeftSquareBracket), "e550324e-63e6-47ef-be0f-4c83c10933c8"}, { new Terminator(DelimiterType.LeftParenthesis), "f6392311-62ca-4784-b919-505bc88a596f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "a1d8212d-7a8c-487f-af11-a09b7a139999") },
		{ "d7769531-8722-4562-a86c-db01e53d2601", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "d7769531-8722-4562-a86c-db01e53d2601") },
		{ "232955bf-eb89-4b2b-b0b2-2a2def84a012", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "232955bf-eb89-4b2b-b0b2-2a2def84a012") },
		{ "53bcac81-472d-472c-ac1b-95ccd69eec62", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "4e38865a-d1bc-4169-b799-4301311eacd7"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "50b109dd-887c-4c05-8dcd-aeb93f1123e4"}, { new NonTerminator(NonTerminatorType.Term), "97581c2e-d208-4adc-9fab-ade5a2117761"}, { new NonTerminator(NonTerminatorType.Factor), "9276cbd1-6198-4aeb-84f6-b6fc682d0742"}, { Terminator.NumberTerminator, "93b819b9-1ca7-4290-97c5-59e1a3cb43f3"}, { new NonTerminator(NonTerminatorType.Variable), "201eceee-4e28-4853-b659-2d8d88b432d7"}, { new Terminator(DelimiterType.LeftParenthesis), "3ef73351-4928-4749-86ef-5788bf2a6588"}, { Terminator.IdentifierTerminator, "5a702cad-386e-49ee-aeb0-2b499a1c6d06"}, { new Terminator(KeywordType.Not), "86f108c6-0588-4301-998d-85cb15b55fb1"}, { new Terminator(OperatorType.Minus), "d4bff7f5-6548-4552-8615-16b1d197f9ae"},}, new Dictionary<Terminator, ReduceInformation>{ }, "53bcac81-472d-472c-ac1b-95ccd69eec62") },
		{ "343bc0df-a720-484c-a7ec-c3f13b014a7e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "1b494715-14e5-451c-a113-08b059c1c24e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "343bc0df-a720-484c-a7ec-c3f13b014a7e") },
		{ "b81770c8-69fc-4aea-85f3-fdbd63baa29a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "6a35efe9-658f-433c-b67d-4fa3596540e9"}, { new NonTerminator(NonTerminatorType.Statement), "7ec830cd-22ff-4a49-ad34-2c6648ddd368"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "b81770c8-69fc-4aea-85f3-fdbd63baa29a") },
		{ "51a07fbf-aaa4-407b-882b-78bcc45b1bc6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "7c7094b2-1033-4dd4-ba91-db4fcdfffcbd"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "51a07fbf-aaa4-407b-882b-78bcc45b1bc6") },
		{ "aab66f1d-f590-4deb-ae68-972232abe638", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "e788ed5c-6303-49fe-8332-381b90cdb5fc"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "aab66f1d-f590-4deb-ae68-972232abe638") },
		{ "f8937803-8908-4014-89c9-d3ee30bd9383", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "f8937803-8908-4014-89c9-d3ee30bd9383") },
		{ "cd08502e-759b-445f-a92a-c64f7b7044c9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "cd08502e-759b-445f-a92a-c64f7b7044c9") },
		{ "4007a2b0-c178-4420-ae43-423f035b0406", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "4007a2b0-c178-4420-ae43-423f035b0406") },
		{ "528e0359-f8c8-4ad3-8321-f3e19847d922", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f4448607-954f-496b-b0d5-3e443d6e7608"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "528e0359-f8c8-4ad3-8321-f3e19847d922") },
		{ "9de280cf-dfc5-4351-babf-dc4706d14f6f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "eac0567e-b12c-4cc7-a71b-ec96193eeb7e"}, { new NonTerminator(NonTerminatorType.IdVarPart), "a4810e1e-db47-4249-8913-fb4c6f882daf"}, { new Terminator(DelimiterType.LeftSquareBracket), "a1b90c1d-2fbf-44ec-925d-5243b9ba4f4e"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "9de280cf-dfc5-4351-babf-dc4706d14f6f") },
		{ "08a8a27a-93fb-4bf6-9994-5a3d304db0f5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "456eae1b-0634-405e-b997-af1654678397"}, { Terminator.NumberTerminator, "cd08502e-759b-445f-a92a-c64f7b7044c9"}, { new NonTerminator(NonTerminatorType.Variable), "4007a2b0-c178-4420-ae43-423f035b0406"}, { new Terminator(DelimiterType.LeftParenthesis), "528e0359-f8c8-4ad3-8321-f3e19847d922"}, { Terminator.IdentifierTerminator, "9de280cf-dfc5-4351-babf-dc4706d14f6f"}, { new Terminator(KeywordType.Not), "08a8a27a-93fb-4bf6-9994-5a3d304db0f5"}, { new Terminator(OperatorType.Minus), "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "08a8a27a-93fb-4bf6-9994-5a3d304db0f5") },
		{ "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "9e2eb25a-bc93-462d-9a2d-976447b921da"}, { Terminator.NumberTerminator, "cd08502e-759b-445f-a92a-c64f7b7044c9"}, { new NonTerminator(NonTerminatorType.Variable), "4007a2b0-c178-4420-ae43-423f035b0406"}, { new Terminator(DelimiterType.LeftParenthesis), "528e0359-f8c8-4ad3-8321-f3e19847d922"}, { Terminator.IdentifierTerminator, "9de280cf-dfc5-4351-babf-dc4706d14f6f"}, { new Terminator(KeywordType.Not), "08a8a27a-93fb-4bf6-9994-5a3d304db0f5"}, { new Terminator(OperatorType.Minus), "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd") },
		{ "0542ee3d-264a-4de5-8617-64787e1b347e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "5006ef3a-a58f-4d87-bfab-6dbff29db55f"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "0542ee3d-264a-4de5-8617-64787e1b347e") },
		{ "2abaf62a-dbe5-4858-8ba6-86d90966607b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "2abaf62a-dbe5-4858-8ba6-86d90966607b") },
		{ "aaf7fe49-2a54-49de-8c50-bd730da289a4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "aaf7fe49-2a54-49de-8c50-bd730da289a4") },
		{ "af50d9a2-1dc6-4ddc-b5be-ce67b3bbb174", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "64e04a51-8101-4c99-8215-edef5adfe1ab"}, { new NonTerminator(NonTerminatorType.Term), "ca0db1cc-eeef-4766-86bd-0972aa88d7d9"}, { new NonTerminator(NonTerminatorType.Factor), "58f680fd-f914-4d3f-a9ed-fb60a1471402"}, { Terminator.NumberTerminator, "f930dc3a-6f4b-4027-8e2a-e90033cf368d"}, { new NonTerminator(NonTerminatorType.Variable), "76c719e8-1e4a-4b53-9642-55e160369cac"}, { new Terminator(DelimiterType.LeftParenthesis), "d6227fe3-5332-41f3-ab13-5057107bce10"}, { Terminator.IdentifierTerminator, "6052705e-8ab3-4feb-8695-54d74284ca66"}, { new Terminator(KeywordType.Not), "f376a735-da5f-4fe9-b205-29a7176e2c96"}, { new Terminator(OperatorType.Minus), "6ea108d2-4583-48c1-acee-c6829c953b48"},}, new Dictionary<Terminator, ReduceInformation>{ }, "af50d9a2-1dc6-4ddc-b5be-ce67b3bbb174") },
		{ "51d510a3-feb9-492b-a5f1-48f65bcf822f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "f6691b3a-e6b8-43c9-9d3a-8b77814cf6e7"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "51d510a3-feb9-492b-a5f1-48f65bcf822f") },
		{ "d3aae3ac-6a20-4ba8-8b94-ee49cba974c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e20e7782-d4dc-4357-9be4-1988bcdd7f3b"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d3aae3ac-6a20-4ba8-8b94-ee49cba974c7") },
		{ "a7e2f5f7-c748-4678-a2d6-12797b8a0ea1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "6a995215-3675-4b10-86c1-ee5a0fbef36f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a7e2f5f7-c748-4678-a2d6-12797b8a0ea1") },
		{ "439ee144-159d-4d2a-bff1-c3a237e69073", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "fb7aaa4a-518f-4181-8234-9266c239a991"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "439ee144-159d-4d2a-bff1-c3a237e69073") },
		{ "f73f2f95-f891-42a2-8292-4b41302acf61", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "f73f2f95-f891-42a2-8292-4b41302acf61") },
		{ "11956c5b-bf6e-494b-9d02-33448bf92371", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "0dc75329-2524-4ff5-8b16-084878cdda67"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "11956c5b-bf6e-494b-9d02-33448bf92371") },
		{ "358957ca-e596-44da-bff9-d5bdad6f2e7d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "358957ca-e596-44da-bff9-d5bdad6f2e7d") },
		{ "58a3b620-774c-489d-9682-cddbce9ac5cb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "58a3b620-774c-489d-9682-cddbce9ac5cb") },
		{ "25b17c7b-97a8-43ac-a728-5808e639fea0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4456ae84-6801-4888-b22b-3c18d9569857"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "25b17c7b-97a8-43ac-a728-5808e639fea0") },
		{ "2fdfc1a2-08ac-4753-a6f8-2aee755b9245", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "05a8abb6-e970-472b-8068-1705de46dc70"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2fdfc1a2-08ac-4753-a6f8-2aee755b9245") },
		{ "80d1f620-8bd2-4471-9f13-483d66a4829a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "507ef70f-cbf9-4805-a7e6-c6c58feaf491"},}, new Dictionary<Terminator, ReduceInformation>{ }, "80d1f620-8bd2-4471-9f13-483d66a4829a") },
		{ "3beb4763-a285-450a-a9bd-e1910cbba9b5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "2d8ddbc3-911f-4f1c-9c9b-119a8d242c8d"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "5c77170c-c181-4031-a687-6cba32502d74"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "3beb4763-a285-450a-a9bd-e1910cbba9b5") },
		{ "4f4146ff-f555-4046-b800-bc3b4bc8c549", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "82e7ffa4-640c-4413-b8cb-3072c4389f33"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "4f4146ff-f555-4046-b800-bc3b4bc8c549") },
		{ "165267cc-114b-433c-b8f4-b069d96d3c59", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "165267cc-114b-433c-b8f4-b069d96d3c59") },
		{ "4b609d98-7fb5-4870-aee2-00a50b1a2c2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a") },
		{ "b857492d-c232-4deb-a3f2-75d23bd3ff58", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "b857492d-c232-4deb-a3f2-75d23bd3ff58") },
		{ "a93e5ebd-bded-47a0-b7f8-dda055e4f013", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "bc5788de-8b1b-40a3-8d57-3dd2115205fe"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a93e5ebd-bded-47a0-b7f8-dda055e4f013") },
		{ "c6152736-1a1f-4d0d-8894-9bc2bbdbde67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "9705d4ee-9961-41f5-ba56-04551065d809"}, { new NonTerminator(NonTerminatorType.IdVarPart), "92d27b65-58de-45e8-b833-54a218c18c8a"}, { new Terminator(DelimiterType.LeftSquareBracket), "09ff4c0a-4a8e-4704-945b-b58ef102bf34"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67") },
		{ "99e20aac-f1d4-49c8-b550-5775ae65df6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f08331b9-f79c-4d30-a82a-6624cf1d40b1"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "99e20aac-f1d4-49c8-b550-5775ae65df6d") },
		{ "621da7b6-7ffa-4f4b-90de-ba132492dd17", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e368c9ab-8144-4d54-8235-f05032da995e"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "621da7b6-7ffa-4f4b-90de-ba132492dd17") },
		{ "cc21909e-1e89-434e-a4b9-bfb34e403767", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramBody))}, }, "cc21909e-1e89-434e-a4b9-bfb34e403767") },
		{ "d59cd94c-e094-4e60-9a84-d5e6aaf822e4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "0bc2457b-e78b-4896-86cd-24fcd2cdd9c1"}, { new NonTerminator(NonTerminatorType.Statement), "7ec830cd-22ff-4a49-ad34-2c6648ddd368"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "d59cd94c-e094-4e60-9a84-d5e6aaf822e4") },
		{ "618a1642-a494-4a2e-9e62-578cb4da299e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "30ba8af7-984c-44b1-9816-e6132ed80a8d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "618a1642-a494-4a2e-9e62-578cb4da299e") },
		{ "8c031ee8-d349-4766-97b0-5e522db5e0f1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "f6d55570-682a-478f-8c35-7f80be5ee590"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "8c031ee8-d349-4766-97b0-5e522db5e0f1") },
		{ "4de0a628-7067-429e-a2ce-9d57086f2ce5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "4de0a628-7067-429e-a2ce-9d57086f2ce5") },
		{ "7294f987-5629-4ddb-b781-31be970fa1d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Parameter), "161abe94-485b-4389-88e0-0f1b4d8c8809"}, { new NonTerminator(NonTerminatorType.VarParameter), "6a7f478b-7211-41a2-b7d5-b6526056fbc2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "5111c4a1-3ed8-496b-9cb6-2371c39683f5"}, { new Terminator(KeywordType.Var), "e28a067a-3740-40f5-b3c8-4fea7d514add"}, { new NonTerminator(NonTerminatorType.IdentifierList), "37a29538-98f5-4309-93af-5b6825ab5170"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7294f987-5629-4ddb-b781-31be970fa1d7") },
		{ "11772442-515b-4412-bb63-dd78776982e8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, }, "11772442-515b-4412-bb63-dd78776982e8") },
		{ "b2474d09-fd52-439a-a9f8-75533980927a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "09549201-ed17-4752-95e5-88dae72d891c"}, { new Terminator(KeywordType.Integer), "16a1feae-ebd8-49ac-a375-74b86d15264e"}, { new Terminator(KeywordType.Real), "c88c04a9-6347-465b-94ea-f46332f9b734"}, { new Terminator(KeywordType.Boolean), "df9661e5-e00b-4feb-9baa-ebd3ef105780"}, { new Terminator(KeywordType.Character), "a0b697ea-71d5-4151-8b3d-2e05576b1f7f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b2474d09-fd52-439a-a9f8-75533980927a") },
		{ "a0b27552-4305-4fb3-b3b8-449fb57524d8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "a0b27552-4305-4fb3-b3b8-449fb57524d8") },
		{ "3bad0549-e2a2-4071-9cc6-8df6540a4ee2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "3bad0549-e2a2-4071-9cc6-8df6540a4ee2") },
		{ "6c29e597-515d-4ae8-a580-c3aebb436c9a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Of), "2f59d10d-5ded-4755-abf8-5c81acf347b7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6c29e597-515d-4ae8-a580-c3aebb436c9a") },
		{ "471bf78d-2fde-476b-9b02-ae3384db4c60", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "5c87d110-279e-4797-ba25-cb58463a96f4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "471bf78d-2fde-476b-9b02-ae3384db4c60") },
		{ "866cb056-9f20-4a70-8167-516a217ddf29", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "54bc38b0-354c-4267-a1bb-8814d8e18ef8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "866cb056-9f20-4a70-8167-516a217ddf29") },
		{ "ccd8d5ac-8fc2-42b2-ab38-88c19e66499d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "67df2c6e-2912-4767-9df8-643874d27f16"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "ccd8d5ac-8fc2-42b2-ab38-88c19e66499d") },
		{ "1ada20ce-16e9-499c-9c9b-a8600ec275e3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "c8850e4a-5fa5-471f-ae33-bc1922e35682"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "1ada20ce-16e9-499c-9c9b-a8600ec275e3") },
		{ "29431af9-c5ae-4e4f-abdc-47baee3c6f6b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "29431af9-c5ae-4e4f-abdc-47baee3c6f6b") },
		{ "67611cf4-fba1-4dfb-b364-ea9ab8cb569f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f") },
		{ "74e351ba-0b8b-42fa-b399-4a9c828d7fdd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "74e351ba-0b8b-42fa-b399-4a9c828d7fdd") },
		{ "a6450c5f-91ef-4c82-8f01-8ccfaf647665", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "e67280ba-60a5-41f6-aa1f-d500f68ea3f3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a6450c5f-91ef-4c82-8f01-8ccfaf647665") },
		{ "40eb9297-c1b8-43cc-9149-c423265fa2c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "37faacda-eeac-4114-820e-2106206afd78"}, { new NonTerminator(NonTerminatorType.IdVarPart), "75375a7e-ebbe-4baf-86ab-fcf3102175eb"}, { new Terminator(DelimiterType.LeftSquareBracket), "c37c7075-9af9-4790-964f-71e6d928cacd"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "40eb9297-c1b8-43cc-9149-c423265fa2c3") },
		{ "eefe5be5-e860-47cb-9b8f-4664ee083437", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "b8963de8-4d9e-4155-95c3-478d6747d951"}, { Terminator.NumberTerminator, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f"}, { new NonTerminator(NonTerminatorType.Variable), "74e351ba-0b8b-42fa-b399-4a9c828d7fdd"}, { new Terminator(DelimiterType.LeftParenthesis), "a6450c5f-91ef-4c82-8f01-8ccfaf647665"}, { Terminator.IdentifierTerminator, "40eb9297-c1b8-43cc-9149-c423265fa2c3"}, { new Terminator(KeywordType.Not), "eefe5be5-e860-47cb-9b8f-4664ee083437"}, { new Terminator(OperatorType.Minus), "67d72f7a-4404-4307-97fa-8e0f58cd710c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eefe5be5-e860-47cb-9b8f-4664ee083437") },
		{ "67d72f7a-4404-4307-97fa-8e0f58cd710c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "c61630e0-107f-42e6-a73a-82f4ddfc25b2"}, { Terminator.NumberTerminator, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f"}, { new NonTerminator(NonTerminatorType.Variable), "74e351ba-0b8b-42fa-b399-4a9c828d7fdd"}, { new Terminator(DelimiterType.LeftParenthesis), "a6450c5f-91ef-4c82-8f01-8ccfaf647665"}, { Terminator.IdentifierTerminator, "40eb9297-c1b8-43cc-9149-c423265fa2c3"}, { new Terminator(KeywordType.Not), "eefe5be5-e860-47cb-9b8f-4664ee083437"}, { new Terminator(OperatorType.Minus), "67d72f7a-4404-4307-97fa-8e0f58cd710c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "67d72f7a-4404-4307-97fa-8e0f58cd710c") },
		{ "2dcef809-d116-4bf0-9699-04f6ec74e270", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "f54f341f-5053-4d91-a494-d5bacd33fb9d"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2dcef809-d116-4bf0-9699-04f6ec74e270") },
		{ "74ddf822-e89f-482c-a292-44ca7132751e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "74ddf822-e89f-482c-a292-44ca7132751e") },
		{ "f0833538-b6f6-4c34-b025-58e7f02aebea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "f0833538-b6f6-4c34-b025-58e7f02aebea") },
		{ "72942bb3-5c71-4fde-8eae-ed95799366c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "faba8d21-c495-495c-ba3c-a865939f1a09"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "72942bb3-5c71-4fde-8eae-ed95799366c2") },
		{ "bddbf2af-982b-4b38-900f-03cd5db89f1e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "f7ebb851-deb8-44c1-b9ed-65f9b544dcf9"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bddbf2af-982b-4b38-900f-03cd5db89f1e") },
		{ "ba2b2529-de0a-43f4-a678-53d15e12c7f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "ba2b2529-de0a-43f4-a678-53d15e12c7f0") },
		{ "97b9cc13-a6f5-480a-b43d-d50f75215e83", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "055a8c5e-fef5-4ddb-a9c4-a97f20d585af"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "97b9cc13-a6f5-480a-b43d-d50f75215e83") },
		{ "b7a4825f-4062-4d84-9739-02c01c149bc1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "46aba7d9-17a1-43bc-975f-75b066d23bc7"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b7a4825f-4062-4d84-9739-02c01c149bc1") },
		{ "b96b8ca6-fae8-49d2-9a85-b2261212d529", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "b96b8ca6-fae8-49d2-9a85-b2261212d529") },
		{ "397f05f9-4803-4d37-86b9-ce4ff549f0c8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "397f05f9-4803-4d37-86b9-ce4ff549f0c8") },
		{ "fd73f990-083b-4660-abc6-f78979120516", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "fd73f990-083b-4660-abc6-f78979120516") },
		{ "54c777e8-bc5d-49e6-ad7c-14a99f440e48", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "52139078-879a-45bb-b710-9beb4497bf5b"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "54c777e8-bc5d-49e6-ad7c-14a99f440e48") },
		{ "05968c73-014d-4743-8f5a-78be96d65756", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "7d52d2d3-115b-4267-9b8b-2a7a5f4bda18"}, { new NonTerminator(NonTerminatorType.IdVarPart), "c08ec95f-d7a7-4ad1-9018-0f211c3e870b"}, { new Terminator(DelimiterType.LeftSquareBracket), "e6f3a707-1dbd-4b32-9915-f915a3bd8ba0"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "05968c73-014d-4743-8f5a-78be96d65756") },
		{ "88fb1eac-0014-40a0-951c-d069fbed21d9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "b49c78d3-05cc-4a0b-8e9d-f2b99b04c9e5"}, { Terminator.NumberTerminator, "397f05f9-4803-4d37-86b9-ce4ff549f0c8"}, { new NonTerminator(NonTerminatorType.Variable), "fd73f990-083b-4660-abc6-f78979120516"}, { new Terminator(DelimiterType.LeftParenthesis), "54c777e8-bc5d-49e6-ad7c-14a99f440e48"}, { Terminator.IdentifierTerminator, "05968c73-014d-4743-8f5a-78be96d65756"}, { new Terminator(KeywordType.Not), "88fb1eac-0014-40a0-951c-d069fbed21d9"}, { new Terminator(OperatorType.Minus), "b539d14c-42bc-4820-8b06-f05d2358b505"},}, new Dictionary<Terminator, ReduceInformation>{ }, "88fb1eac-0014-40a0-951c-d069fbed21d9") },
		{ "b539d14c-42bc-4820-8b06-f05d2358b505", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "783db48c-d4a6-4e8d-9d7b-e2b616a224ea"}, { Terminator.NumberTerminator, "397f05f9-4803-4d37-86b9-ce4ff549f0c8"}, { new NonTerminator(NonTerminatorType.Variable), "fd73f990-083b-4660-abc6-f78979120516"}, { new Terminator(DelimiterType.LeftParenthesis), "54c777e8-bc5d-49e6-ad7c-14a99f440e48"}, { Terminator.IdentifierTerminator, "05968c73-014d-4743-8f5a-78be96d65756"}, { new Terminator(KeywordType.Not), "88fb1eac-0014-40a0-951c-d069fbed21d9"}, { new Terminator(OperatorType.Minus), "b539d14c-42bc-4820-8b06-f05d2358b505"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b539d14c-42bc-4820-8b06-f05d2358b505") },
		{ "3f73623b-19fb-4bea-ae5c-385684a7dd11", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "4aa8465a-5d02-4525-9106-965aac2e2de8"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "3f73623b-19fb-4bea-ae5c-385684a7dd11") },
		{ "ef3b5b88-5ef2-49f3-8eb5-f41a0f794e5b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "ef3b5b88-5ef2-49f3-8eb5-f41a0f794e5b") },
		{ "a39a2e4b-ba52-4be3-bd28-ebc0359049b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "a39a2e4b-ba52-4be3-bd28-ebc0359049b9") },
		{ "96d9601f-f194-4f30-a774-e3e06703111a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8ad01c87-2eb2-4e2a-a92d-1b1418d04f1a"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "96d9601f-f194-4f30-a774-e3e06703111a") },
		{ "678424ee-f442-4b9f-b68f-2cca6e55747a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "50414b53-e369-47d1-a802-0d8708982ba9"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "678424ee-f442-4b9f-b68f-2cca6e55747a") },
		{ "90569cb6-c35a-467a-ba20-6aa7e4cb215d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "90569cb6-c35a-467a-ba20-6aa7e4cb215d") },
		{ "fd0c3935-1ce8-4297-9736-0847f1f73ffc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "6b4a41d7-b2c2-4b35-9dab-247e79c519bb"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "fd0c3935-1ce8-4297-9736-0847f1f73ffc") },
		{ "dc433b60-bf73-428e-bffd-439333af01e3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d006983d-4992-4977-b35a-409be1bd8de6"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "dc433b60-bf73-428e-bffd-439333af01e3") },
		{ "3c3b1067-f688-4177-b4a8-3d532ad969f8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "3c3b1067-f688-4177-b4a8-3d532ad969f8") },
		{ "6a8eb5f2-a94a-4327-873b-e6ad58275b47", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6a8eb5f2-a94a-4327-873b-e6ad58275b47") },
		{ "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee") },
		{ "4b46b06f-888d-4c1a-8d7d-5131996ac388", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "9663167d-ecd7-4076-8664-44d1b0aed65a"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4b46b06f-888d-4c1a-8d7d-5131996ac388") },
		{ "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "9f2d57f3-0ff8-451e-a8e8-77f46b144be1"}, { new NonTerminator(NonTerminatorType.IdVarPart), "76e64bdd-7197-4bab-83be-9f57b69023dc"}, { new Terminator(DelimiterType.LeftSquareBracket), "115a925a-686e-4af7-aca0-e4c3f81b2aa7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11") },
		{ "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "08d70b92-4006-4781-9cd5-55031d1d0b2a"}, { Terminator.NumberTerminator, "6a8eb5f2-a94a-4327-873b-e6ad58275b47"}, { new NonTerminator(NonTerminatorType.Variable), "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee"}, { new Terminator(DelimiterType.LeftParenthesis), "4b46b06f-888d-4c1a-8d7d-5131996ac388"}, { Terminator.IdentifierTerminator, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11"}, { new Terminator(KeywordType.Not), "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2"}, { new Terminator(OperatorType.Minus), "26c11d2c-df29-4059-adab-949a192a3c76"},}, new Dictionary<Terminator, ReduceInformation>{ }, "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2") },
		{ "26c11d2c-df29-4059-adab-949a192a3c76", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4361334f-455a-49bb-b204-a42f9ae48bac"}, { Terminator.NumberTerminator, "6a8eb5f2-a94a-4327-873b-e6ad58275b47"}, { new NonTerminator(NonTerminatorType.Variable), "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee"}, { new Terminator(DelimiterType.LeftParenthesis), "4b46b06f-888d-4c1a-8d7d-5131996ac388"}, { Terminator.IdentifierTerminator, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11"}, { new Terminator(KeywordType.Not), "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2"}, { new Terminator(OperatorType.Minus), "26c11d2c-df29-4059-adab-949a192a3c76"},}, new Dictionary<Terminator, ReduceInformation>{ }, "26c11d2c-df29-4059-adab-949a192a3c76") },
		{ "ff7b43b3-3ab3-40cd-a9e2-dd6e08e53314", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "47ead8ca-782f-4e56-8a62-5c47c0e006e1"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ff7b43b3-3ab3-40cd-a9e2-dd6e08e53314") },
		{ "3a49f7dc-9fab-4956-b28f-39573872dd53", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "3a49f7dc-9fab-4956-b28f-39573872dd53") },
		{ "a34e6d77-a025-4217-bf30-30c698c350f8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "a34e6d77-a025-4217-bf30-30c698c350f8") },
		{ "14642f27-d700-44b3-85b8-d4bc6274a4c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "deaba6d4-2001-4da5-889b-91b57af8608f"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "14642f27-d700-44b3-85b8-d4bc6274a4c2") },
		{ "2aec9def-baaa-41be-a70e-de9288e7e391", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "af95010e-8001-44ce-a188-8a1b5a3a3df1"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2aec9def-baaa-41be-a70e-de9288e7e391") },
		{ "96521b5b-054e-4e01-aec3-30f3a8028d85", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "96521b5b-054e-4e01-aec3-30f3a8028d85") },
		{ "0ce5369e-9dc5-4826-ba82-3ed963f0278c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "2d2b4fd6-e36d-4b3a-a5b6-0bb1ea4d0b8a"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "0ce5369e-9dc5-4826-ba82-3ed963f0278c") },
		{ "c4942b9a-4e6e-4dac-8723-bd97e21b9f51", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "cc7cd05c-900e-4688-a63c-d42005bd8244"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "f4b52a55-c024-4715-b6dc-6006672ccb19"}, { new NonTerminator(NonTerminatorType.Term), "2848856f-b5c9-4130-8df3-93e64aa25fba"}, { new NonTerminator(NonTerminatorType.Factor), "12d20e8a-78e0-43f4-8830-e6a0e7af4c21"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c4942b9a-4e6e-4dac-8723-bd97e21b9f51") },
		{ "05003d6c-68bb-4d3f-a153-c110b41aa43c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "b6453340-4356-41e2-92ba-96708bacce00"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "f4b52a55-c024-4715-b6dc-6006672ccb19"}, { new NonTerminator(NonTerminatorType.Term), "2848856f-b5c9-4130-8df3-93e64aa25fba"}, { new NonTerminator(NonTerminatorType.Factor), "12d20e8a-78e0-43f4-8830-e6a0e7af4c21"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "05003d6c-68bb-4d3f-a153-c110b41aa43c") },
		{ "f6392311-62ca-4784-b919-505bc88a596f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "693ec128-7246-4331-a861-19f1d87092ed"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f6392311-62ca-4784-b919-505bc88a596f") },
		{ "4e38865a-d1bc-4169-b799-4301311eacd7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "52783dc7-db2d-4bde-a16e-0dd9d881592f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4e38865a-d1bc-4169-b799-4301311eacd7") },
		{ "1b494715-14e5-451c-a113-08b059c1c24e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "c2f516c5-0d8f-4869-a661-2d6be33e865b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1b494715-14e5-451c-a113-08b059c1c24e") },
		{ "6a35efe9-658f-433c-b67d-4fa3596540e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "274d3e22-1ad4-4b9d-b505-f06936ee467e"}, { new Terminator(DelimiterType.Semicolon), "6539c4c8-777a-4559-bee6-f6d854880735"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6a35efe9-658f-433c-b67d-4fa3596540e9") },
		{ "7c7094b2-1033-4dd4-ba91-db4fcdfffcbd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "c8fe07c7-cb87-4261-9ebd-63c550b677c5"}, { new NonTerminator(NonTerminatorType.Factor), "f8937803-8908-4014-89c9-d3ee30bd9383"}, { Terminator.NumberTerminator, "cd08502e-759b-445f-a92a-c64f7b7044c9"}, { new NonTerminator(NonTerminatorType.Variable), "4007a2b0-c178-4420-ae43-423f035b0406"}, { new Terminator(DelimiterType.LeftParenthesis), "528e0359-f8c8-4ad3-8321-f3e19847d922"}, { Terminator.IdentifierTerminator, "9de280cf-dfc5-4351-babf-dc4706d14f6f"}, { new Terminator(KeywordType.Not), "08a8a27a-93fb-4bf6-9994-5a3d304db0f5"}, { new Terminator(OperatorType.Minus), "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7c7094b2-1033-4dd4-ba91-db4fcdfffcbd") },
		{ "e788ed5c-6303-49fe-8332-381b90cdb5fc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "1d5708e8-74c6-43aa-ae3d-3f7c50432ec9"}, { Terminator.NumberTerminator, "cd08502e-759b-445f-a92a-c64f7b7044c9"}, { new NonTerminator(NonTerminatorType.Variable), "4007a2b0-c178-4420-ae43-423f035b0406"}, { new Terminator(DelimiterType.LeftParenthesis), "528e0359-f8c8-4ad3-8321-f3e19847d922"}, { Terminator.IdentifierTerminator, "9de280cf-dfc5-4351-babf-dc4706d14f6f"}, { new Terminator(KeywordType.Not), "08a8a27a-93fb-4bf6-9994-5a3d304db0f5"}, { new Terminator(OperatorType.Minus), "570a9b9f-ec6b-4ab3-beb5-415d9d8d71bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e788ed5c-6303-49fe-8332-381b90cdb5fc") },
		{ "f4448607-954f-496b-b0d5-3e443d6e7608", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4e59346b-9d26-4777-b6ff-00c698fe6350"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f4448607-954f-496b-b0d5-3e443d6e7608") },
		{ "eac0567e-b12c-4cc7-a71b-ec96193eeb7e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "7839987b-51e5-4409-ac26-a85a45ec24ec"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eac0567e-b12c-4cc7-a71b-ec96193eeb7e") },
		{ "a4810e1e-db47-4249-8913-fb4c6f882daf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "a4810e1e-db47-4249-8913-fb4c6f882daf") },
		{ "a1b90c1d-2fbf-44ec-925d-5243b9ba4f4e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "1661d383-8c81-4120-a961-b9dce4b6e5ca"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a1b90c1d-2fbf-44ec-925d-5243b9ba4f4e") },
		{ "456eae1b-0634-405e-b997-af1654678397", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "456eae1b-0634-405e-b997-af1654678397") },
		{ "9e2eb25a-bc93-462d-9a2d-976447b921da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "9e2eb25a-bc93-462d-9a2d-976447b921da") },
		{ "64e04a51-8101-4c99-8215-edef5adfe1ab", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "4f83fa18-00b6-4e07-80f9-1a85637a5643"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "64e04a51-8101-4c99-8215-edef5adfe1ab") },
		{ "ca0db1cc-eeef-4766-86bd-0972aa88d7d9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "bdf8765d-283f-41e7-966c-2a54a4b6afe4"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ca0db1cc-eeef-4766-86bd-0972aa88d7d9") },
		{ "58f680fd-f914-4d3f-a9ed-fb60a1471402", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "58f680fd-f914-4d3f-a9ed-fb60a1471402") },
		{ "f930dc3a-6f4b-4027-8e2a-e90033cf368d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "f930dc3a-6f4b-4027-8e2a-e90033cf368d") },
		{ "76c719e8-1e4a-4b53-9642-55e160369cac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "76c719e8-1e4a-4b53-9642-55e160369cac") },
		{ "d6227fe3-5332-41f3-ab13-5057107bce10", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "1f2ea4f7-0ffb-4854-a0a3-3c2f97d9747f"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d6227fe3-5332-41f3-ab13-5057107bce10") },
		{ "6052705e-8ab3-4feb-8695-54d74284ca66", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "62026db8-4d12-451a-93c8-4fbf3b11877b"}, { new NonTerminator(NonTerminatorType.IdVarPart), "afe9f26c-35f4-4ce1-b79f-3970a0335675"}, { new Terminator(DelimiterType.LeftSquareBracket), "7c05d619-5dbc-4015-995e-b1df5b1d8850"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "6052705e-8ab3-4feb-8695-54d74284ca66") },
		{ "f376a735-da5f-4fe9-b205-29a7176e2c96", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "87f426a2-508c-447a-bc79-5c945c4b9608"}, { Terminator.NumberTerminator, "f930dc3a-6f4b-4027-8e2a-e90033cf368d"}, { new NonTerminator(NonTerminatorType.Variable), "76c719e8-1e4a-4b53-9642-55e160369cac"}, { new Terminator(DelimiterType.LeftParenthesis), "d6227fe3-5332-41f3-ab13-5057107bce10"}, { Terminator.IdentifierTerminator, "6052705e-8ab3-4feb-8695-54d74284ca66"}, { new Terminator(KeywordType.Not), "f376a735-da5f-4fe9-b205-29a7176e2c96"}, { new Terminator(OperatorType.Minus), "6ea108d2-4583-48c1-acee-c6829c953b48"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f376a735-da5f-4fe9-b205-29a7176e2c96") },
		{ "6ea108d2-4583-48c1-acee-c6829c953b48", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "9a641d8a-27bf-412f-83b5-8347f0a8d5e6"}, { Terminator.NumberTerminator, "f930dc3a-6f4b-4027-8e2a-e90033cf368d"}, { new NonTerminator(NonTerminatorType.Variable), "76c719e8-1e4a-4b53-9642-55e160369cac"}, { new Terminator(DelimiterType.LeftParenthesis), "d6227fe3-5332-41f3-ab13-5057107bce10"}, { Terminator.IdentifierTerminator, "6052705e-8ab3-4feb-8695-54d74284ca66"}, { new Terminator(KeywordType.Not), "f376a735-da5f-4fe9-b205-29a7176e2c96"}, { new Terminator(OperatorType.Minus), "6ea108d2-4583-48c1-acee-c6829c953b48"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6ea108d2-4583-48c1-acee-c6829c953b48") },
		{ "f6691b3a-e6b8-43c9-9d3a-8b77814cf6e7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d3aae3ac-6a20-4ba8-8b94-ee49cba974c7"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "f6691b3a-e6b8-43c9-9d3a-8b77814cf6e7") },
		{ "e20e7782-d4dc-4357-9be4-1988bcdd7f3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "e20e7782-d4dc-4357-9be4-1988bcdd7f3b") },
		{ "6a995215-3675-4b10-86c1-ee5a0fbef36f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "6a995215-3675-4b10-86c1-ee5a0fbef36f") },
		{ "fb7aaa4a-518f-4181-8234-9266c239a991", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "baccb7b7-a262-445d-9f01-35dad91786cb"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fb7aaa4a-518f-4181-8234-9266c239a991") },
		{ "0dc75329-2524-4ff5-8b16-084878cdda67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "382a159f-2ba9-4c57-92db-d473b1e713b1"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0dc75329-2524-4ff5-8b16-084878cdda67") },
		{ "4456ae84-6801-4888-b22b-3c18d9569857", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "4456ae84-6801-4888-b22b-3c18d9569857") },
		{ "05a8abb6-e970-472b-8068-1705de46dc70", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "05a8abb6-e970-472b-8068-1705de46dc70") },
		{ "507ef70f-cbf9-4805-a7e6-c6c58feaf491", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "b6764215-970e-4c4e-b623-a915a5440e57"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "6baf1069-e017-49f8-bc03-41493e396198"}, { new NonTerminator(NonTerminatorType.Term), "77edd341-4912-4ec6-9683-0e8edd08e541"}, { new NonTerminator(NonTerminatorType.Factor), "7eb5aa71-c08f-422a-8d32-5364d19d69fb"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "507ef70f-cbf9-4805-a7e6-c6c58feaf491") },
		{ "2d8ddbc3-911f-4f1c-9c9b-119a8d242c8d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "e46438e1-766f-4d06-b6d1-a67442d27824"}, { new NonTerminator(NonTerminatorType.Term), "b218f401-dff9-4968-b9d1-a7eb4deabdd6"}, { new NonTerminator(NonTerminatorType.Factor), "d638731c-5d03-477c-a0a6-93f866022f1c"}, { Terminator.NumberTerminator, "979daaa7-74d6-437e-a947-0484c4e6f9e9"}, { new NonTerminator(NonTerminatorType.Variable), "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8"}, { new Terminator(DelimiterType.LeftParenthesis), "3fcf844f-0051-4f12-8247-561b25885410"}, { Terminator.IdentifierTerminator, "07babfee-20d5-4a84-b812-4f030a7ec54d"}, { new Terminator(KeywordType.Not), "4022df3b-2f23-483c-841b-8a0211dc57e7"}, { new Terminator(OperatorType.Minus), "0270f9d3-5591-47f2-8108-c2cf69bdb734"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2d8ddbc3-911f-4f1c-9c9b-119a8d242c8d") },
		{ "5c77170c-c181-4031-a687-6cba32502d74", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "81dbd81e-9dee-449f-8236-b4b7951cacb6"}, { new NonTerminator(NonTerminatorType.Factor), "165267cc-114b-433c-b8f4-b069d96d3c59"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5c77170c-c181-4031-a687-6cba32502d74") },
		{ "82e7ffa4-640c-4413-b8cb-3072c4389f33", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "6d232c84-78b1-4eb1-b87c-0419274c2ac2"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "82e7ffa4-640c-4413-b8cb-3072c4389f33") },
		{ "bc5788de-8b1b-40a3-8d57-3dd2115205fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "12a6fb19-d41c-426b-8526-4e6036f352f6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bc5788de-8b1b-40a3-8d57-3dd2115205fe") },
		{ "9705d4ee-9961-41f5-ba56-04551065d809", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "91d186ef-da4e-4cef-8640-6df487c1b092"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9705d4ee-9961-41f5-ba56-04551065d809") },
		{ "92d27b65-58de-45e8-b833-54a218c18c8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "92d27b65-58de-45e8-b833-54a218c18c8a") },
		{ "09ff4c0a-4a8e-4704-945b-b58ef102bf34", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "646c0a5f-80b7-4a7a-b94b-cf27267b2e46"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "09ff4c0a-4a8e-4704-945b-b58ef102bf34") },
		{ "f08331b9-f79c-4d30-a82a-6624cf1d40b1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "f08331b9-f79c-4d30-a82a-6624cf1d40b1") },
		{ "e368c9ab-8144-4d54-8235-f05032da995e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "e368c9ab-8144-4d54-8235-f05032da995e") },
		{ "0bc2457b-e78b-4896-86cd-24fcd2cdd9c1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "619c6f1e-1f7c-408b-9632-3b7ac8942358"}, { new Terminator(DelimiterType.Semicolon), "6539c4c8-777a-4559-bee6-f6d854880735"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0bc2457b-e78b-4896-86cd-24fcd2cdd9c1") },
		{ "30ba8af7-984c-44b1-9816-e6132ed80a8d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "11d34202-306d-49bd-949b-40294e9d988f"}, { Terminator.IdentifierTerminator, "c5b02395-6a16-42ea-b32a-eb56cf6039ee"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "30ba8af7-984c-44b1-9816-e6132ed80a8d") },
		{ "161abe94-485b-4389-88e0-0f1b4d8c8809", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, }, "161abe94-485b-4389-88e0-0f1b4d8c8809") },
		{ "09549201-ed17-4752-95e5-88dae72d891c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, }, "09549201-ed17-4752-95e5-88dae72d891c") },
		{ "16a1feae-ebd8-49ac-a375-74b86d15264e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "16a1feae-ebd8-49ac-a375-74b86d15264e") },
		{ "c88c04a9-6347-465b-94ea-f46332f9b734", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "c88c04a9-6347-465b-94ea-f46332f9b734") },
		{ "df9661e5-e00b-4feb-9baa-ebd3ef105780", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "df9661e5-e00b-4feb-9baa-ebd3ef105780") },
		{ "a0b697ea-71d5-4151-8b3d-2e05576b1f7f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "a0b697ea-71d5-4151-8b3d-2e05576b1f7f") },
		{ "2f59d10d-5ded-4755-abf8-5c81acf347b7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "ae7dc6e3-edcf-4492-85c8-9354c0d37049"}, { new Terminator(KeywordType.Integer), "ed80790b-88ef-4371-b0e7-81e94e5fac45"}, { new Terminator(KeywordType.Real), "7388243b-8ed7-4285-8409-382eea2bf0ac"}, { new Terminator(KeywordType.Boolean), "f8beec53-4b1a-49ba-b0a2-ca9d0a59f346"}, { new Terminator(KeywordType.Character), "84689f95-8766-49ca-bbc4-f5cb0b102e39"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2f59d10d-5ded-4755-abf8-5c81acf347b7") },
		{ "5c87d110-279e-4797-ba25-cb58463a96f4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "2dbfcd41-8fcb-42fe-b259-890e488861c1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5c87d110-279e-4797-ba25-cb58463a96f4") },
		{ "54bc38b0-354c-4267-a1bb-8814d8e18ef8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, }, "54bc38b0-354c-4267-a1bb-8814d8e18ef8") },
		{ "67df2c6e-2912-4767-9df8-643874d27f16", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "2365ec70-6eba-4014-8011-295bf3b64670"}, { new NonTerminator(NonTerminatorType.Factor), "29431af9-c5ae-4e4f-abdc-47baee3c6f6b"}, { Terminator.NumberTerminator, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f"}, { new NonTerminator(NonTerminatorType.Variable), "74e351ba-0b8b-42fa-b399-4a9c828d7fdd"}, { new Terminator(DelimiterType.LeftParenthesis), "a6450c5f-91ef-4c82-8f01-8ccfaf647665"}, { Terminator.IdentifierTerminator, "40eb9297-c1b8-43cc-9149-c423265fa2c3"}, { new Terminator(KeywordType.Not), "eefe5be5-e860-47cb-9b8f-4664ee083437"}, { new Terminator(OperatorType.Minus), "67d72f7a-4404-4307-97fa-8e0f58cd710c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "67df2c6e-2912-4767-9df8-643874d27f16") },
		{ "c8850e4a-5fa5-471f-ae33-bc1922e35682", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "8784ad51-d3fa-40d4-a867-d9a66f959e93"}, { Terminator.NumberTerminator, "67611cf4-fba1-4dfb-b364-ea9ab8cb569f"}, { new NonTerminator(NonTerminatorType.Variable), "74e351ba-0b8b-42fa-b399-4a9c828d7fdd"}, { new Terminator(DelimiterType.LeftParenthesis), "a6450c5f-91ef-4c82-8f01-8ccfaf647665"}, { Terminator.IdentifierTerminator, "40eb9297-c1b8-43cc-9149-c423265fa2c3"}, { new Terminator(KeywordType.Not), "eefe5be5-e860-47cb-9b8f-4664ee083437"}, { new Terminator(OperatorType.Minus), "67d72f7a-4404-4307-97fa-8e0f58cd710c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c8850e4a-5fa5-471f-ae33-bc1922e35682") },
		{ "e67280ba-60a5-41f6-aa1f-d500f68ea3f3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "c0b61b00-2687-40dd-9052-527ead30bc36"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e67280ba-60a5-41f6-aa1f-d500f68ea3f3") },
		{ "37faacda-eeac-4114-820e-2106206afd78", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "43fe5aa6-297d-40b5-bf42-67113c0ec3af"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "37faacda-eeac-4114-820e-2106206afd78") },
		{ "75375a7e-ebbe-4baf-86ab-fcf3102175eb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "75375a7e-ebbe-4baf-86ab-fcf3102175eb") },
		{ "c37c7075-9af9-4790-964f-71e6d928cacd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "f10c735b-c152-4f1a-826c-2feceb2174ec"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c37c7075-9af9-4790-964f-71e6d928cacd") },
		{ "b8963de8-4d9e-4155-95c3-478d6747d951", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "b8963de8-4d9e-4155-95c3-478d6747d951") },
		{ "c61630e0-107f-42e6-a73a-82f4ddfc25b2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "c61630e0-107f-42e6-a73a-82f4ddfc25b2") },
		{ "faba8d21-c495-495c-ba3c-a865939f1a09", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "faba8d21-c495-495c-ba3c-a865939f1a09") },
		{ "f7ebb851-deb8-44c1-b9ed-65f9b544dcf9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "f7ebb851-deb8-44c1-b9ed-65f9b544dcf9") },
		{ "055a8c5e-fef5-4ddb-a9c4-a97f20d585af", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "30434d67-0dd0-40b0-95c8-b158d6b5c266"}, { new NonTerminator(NonTerminatorType.Factor), "b96b8ca6-fae8-49d2-9a85-b2261212d529"}, { Terminator.NumberTerminator, "397f05f9-4803-4d37-86b9-ce4ff549f0c8"}, { new NonTerminator(NonTerminatorType.Variable), "fd73f990-083b-4660-abc6-f78979120516"}, { new Terminator(DelimiterType.LeftParenthesis), "54c777e8-bc5d-49e6-ad7c-14a99f440e48"}, { Terminator.IdentifierTerminator, "05968c73-014d-4743-8f5a-78be96d65756"}, { new Terminator(KeywordType.Not), "88fb1eac-0014-40a0-951c-d069fbed21d9"}, { new Terminator(OperatorType.Minus), "b539d14c-42bc-4820-8b06-f05d2358b505"},}, new Dictionary<Terminator, ReduceInformation>{ }, "055a8c5e-fef5-4ddb-a9c4-a97f20d585af") },
		{ "46aba7d9-17a1-43bc-975f-75b066d23bc7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "5fa3bfe5-e519-4fa2-9604-943f1b5761c6"}, { Terminator.NumberTerminator, "397f05f9-4803-4d37-86b9-ce4ff549f0c8"}, { new NonTerminator(NonTerminatorType.Variable), "fd73f990-083b-4660-abc6-f78979120516"}, { new Terminator(DelimiterType.LeftParenthesis), "54c777e8-bc5d-49e6-ad7c-14a99f440e48"}, { Terminator.IdentifierTerminator, "05968c73-014d-4743-8f5a-78be96d65756"}, { new Terminator(KeywordType.Not), "88fb1eac-0014-40a0-951c-d069fbed21d9"}, { new Terminator(OperatorType.Minus), "b539d14c-42bc-4820-8b06-f05d2358b505"},}, new Dictionary<Terminator, ReduceInformation>{ }, "46aba7d9-17a1-43bc-975f-75b066d23bc7") },
		{ "52139078-879a-45bb-b710-9beb4497bf5b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "347f8aa8-8d3b-4ec5-9480-d51368a59a58"},}, new Dictionary<Terminator, ReduceInformation>{ }, "52139078-879a-45bb-b710-9beb4497bf5b") },
		{ "7d52d2d3-115b-4267-9b8b-2a7a5f4bda18", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "233b5bc9-6e08-440e-bfd1-cb4711b50495"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7d52d2d3-115b-4267-9b8b-2a7a5f4bda18") },
		{ "c08ec95f-d7a7-4ad1-9018-0f211c3e870b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "c08ec95f-d7a7-4ad1-9018-0f211c3e870b") },
		{ "e6f3a707-1dbd-4b32-9915-f915a3bd8ba0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "f445ed10-a97b-48d7-87ce-e7b56123fb64"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e6f3a707-1dbd-4b32-9915-f915a3bd8ba0") },
		{ "b49c78d3-05cc-4a0b-8e9d-f2b99b04c9e5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "b49c78d3-05cc-4a0b-8e9d-f2b99b04c9e5") },
		{ "783db48c-d4a6-4e8d-9d7b-e2b616a224ea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "783db48c-d4a6-4e8d-9d7b-e2b616a224ea") },
		{ "8ad01c87-2eb2-4e2a-a92d-1b1418d04f1a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "8ad01c87-2eb2-4e2a-a92d-1b1418d04f1a") },
		{ "50414b53-e369-47d1-a802-0d8708982ba9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "50414b53-e369-47d1-a802-0d8708982ba9") },
		{ "6b4a41d7-b2c2-4b35-9dab-247e79c519bb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "467aab78-6373-405c-97e0-3943501ef0b9"}, { new NonTerminator(NonTerminatorType.Factor), "3c3b1067-f688-4177-b4a8-3d532ad969f8"}, { Terminator.NumberTerminator, "6a8eb5f2-a94a-4327-873b-e6ad58275b47"}, { new NonTerminator(NonTerminatorType.Variable), "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee"}, { new Terminator(DelimiterType.LeftParenthesis), "4b46b06f-888d-4c1a-8d7d-5131996ac388"}, { Terminator.IdentifierTerminator, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11"}, { new Terminator(KeywordType.Not), "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2"}, { new Terminator(OperatorType.Minus), "26c11d2c-df29-4059-adab-949a192a3c76"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6b4a41d7-b2c2-4b35-9dab-247e79c519bb") },
		{ "d006983d-4992-4977-b35a-409be1bd8de6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "fba2fbb1-b310-40f5-b069-991fa81e31c0"}, { Terminator.NumberTerminator, "6a8eb5f2-a94a-4327-873b-e6ad58275b47"}, { new NonTerminator(NonTerminatorType.Variable), "96c84e8f-26ad-4762-b8ea-e7fdb36cd9ee"}, { new Terminator(DelimiterType.LeftParenthesis), "4b46b06f-888d-4c1a-8d7d-5131996ac388"}, { Terminator.IdentifierTerminator, "80cfce0b-0aa7-47b3-b7ff-c4ff2c4e6b11"}, { new Terminator(KeywordType.Not), "21d9ccb6-ffd2-456d-92ad-5ddded20e7d2"}, { new Terminator(OperatorType.Minus), "26c11d2c-df29-4059-adab-949a192a3c76"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d006983d-4992-4977-b35a-409be1bd8de6") },
		{ "9663167d-ecd7-4076-8664-44d1b0aed65a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "3514bf8a-669e-4b39-9124-830aacfa113a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9663167d-ecd7-4076-8664-44d1b0aed65a") },
		{ "9f2d57f3-0ff8-451e-a8e8-77f46b144be1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "dc06b371-cb33-4979-a436-fe879811593f"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9f2d57f3-0ff8-451e-a8e8-77f46b144be1") },
		{ "76e64bdd-7197-4bab-83be-9f57b69023dc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "76e64bdd-7197-4bab-83be-9f57b69023dc") },
		{ "115a925a-686e-4af7-aca0-e4c3f81b2aa7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "24d96ade-bcaf-49fd-9386-d8143675db95"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "115a925a-686e-4af7-aca0-e4c3f81b2aa7") },
		{ "08d70b92-4006-4781-9cd5-55031d1d0b2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "08d70b92-4006-4781-9cd5-55031d1d0b2a") },
		{ "4361334f-455a-49bb-b204-a42f9ae48bac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "4361334f-455a-49bb-b204-a42f9ae48bac") },
		{ "deaba6d4-2001-4da5-889b-91b57af8608f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "deaba6d4-2001-4da5-889b-91b57af8608f") },
		{ "af95010e-8001-44ce-a188-8a1b5a3a3df1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "af95010e-8001-44ce-a188-8a1b5a3a3df1") },
		{ "2d2b4fd6-e36d-4b3a-a5b6-0bb1ea4d0b8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "2d2b4fd6-e36d-4b3a-a5b6-0bb1ea4d0b8a") },
		{ "cc7cd05c-900e-4688-a63c-d42005bd8244", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "cc7cd05c-900e-4688-a63c-d42005bd8244") },
		{ "f4b52a55-c024-4715-b6dc-6006672ccb19", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "12ca8229-7472-443a-92d0-7271a9bfbe07"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "35bfc9e2-4796-4be8-82b9-d04d62aa91aa"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "f4b52a55-c024-4715-b6dc-6006672ccb19") },
		{ "2848856f-b5c9-4130-8df3-93e64aa25fba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "738a8ae5-c9ba-4a05-b4f8-3bb7fa5cab72"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2848856f-b5c9-4130-8df3-93e64aa25fba") },
		{ "12d20e8a-78e0-43f4-8830-e6a0e7af4c21", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "12d20e8a-78e0-43f4-8830-e6a0e7af4c21") },
		{ "57590ab0-600a-45be-82f5-329e29ea00e3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "57590ab0-600a-45be-82f5-329e29ea00e3") },
		{ "7d99968e-f678-475d-9161-34566f505e53", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "7d99968e-f678-475d-9161-34566f505e53") },
		{ "7aac5197-8c61-408d-a62b-911e7ad47adf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "a18441aa-def0-4be9-8f95-149515799004"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7aac5197-8c61-408d-a62b-911e7ad47adf") },
		{ "bd6d4b98-725a-4ba1-ac88-757e5832e3d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "6e247029-5710-4182-a5ec-ef2797656e2e"}, { new NonTerminator(NonTerminatorType.IdVarPart), "96416a71-2054-458b-b4c6-28991c3e33ea"}, { new Terminator(DelimiterType.LeftSquareBracket), "5bcba7e7-ce11-44d3-a0cc-566333ae1554"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0") },
		{ "fdef1166-94b0-4796-bc24-30c6a09a5277", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "77d4b6a0-72ec-44c5-8772-886454b803aa"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fdef1166-94b0-4796-bc24-30c6a09a5277") },
		{ "b5f3035f-427c-4c1c-b77b-752608a50215", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "0fdb49b0-be6a-4b0a-80cd-ad8a192879c0"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b5f3035f-427c-4c1c-b77b-752608a50215") },
		{ "b6453340-4356-41e2-92ba-96708bacce00", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "b6453340-4356-41e2-92ba-96708bacce00") },
		{ "693ec128-7246-4331-a861-19f1d87092ed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "d64dfbf1-cbbc-4e8c-a678-284de76d2413"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "693ec128-7246-4331-a861-19f1d87092ed") },
		{ "52783dc7-db2d-4bde-a16e-0dd9d881592f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "de0fd8e5-8027-4d7d-be8a-ce62a8e1c512"}, { new NonTerminator(NonTerminatorType.Variable), "b673a04f-5b49-48ea-b31a-e543bb450990"}, { Terminator.IdentifierTerminator, "a1d8212d-7a8c-487f-af11-a09b7a139999"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "d7769531-8722-4562-a86c-db01e53d2601"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "232955bf-eb89-4b2b-b0b2-2a2def84a012"}, { new Terminator(KeywordType.If), "53bcac81-472d-472c-ac1b-95ccd69eec62"}, { new Terminator(KeywordType.For), "343bc0df-a720-484c-a7ec-c3f13b014a7e"}, { new Terminator(KeywordType.Begin), "b81770c8-69fc-4aea-85f3-fdbd63baa29a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "52783dc7-db2d-4bde-a16e-0dd9d881592f") },
		{ "c2f516c5-0d8f-4869-a661-2d6be33e865b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "6ada1aba-a74f-4f76-87ba-f74f4ae26be2"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "3beb4763-a285-450a-a9bd-e1910cbba9b5"}, { new NonTerminator(NonTerminatorType.Term), "4f4146ff-f555-4046-b800-bc3b4bc8c549"}, { new NonTerminator(NonTerminatorType.Factor), "165267cc-114b-433c-b8f4-b069d96d3c59"}, { Terminator.NumberTerminator, "4b609d98-7fb5-4870-aee2-00a50b1a2c2a"}, { new NonTerminator(NonTerminatorType.Variable), "b857492d-c232-4deb-a3f2-75d23bd3ff58"}, { new Terminator(DelimiterType.LeftParenthesis), "a93e5ebd-bded-47a0-b7f8-dda055e4f013"}, { Terminator.IdentifierTerminator, "c6152736-1a1f-4d0d-8894-9bc2bbdbde67"}, { new Terminator(KeywordType.Not), "99e20aac-f1d4-49c8-b550-5775ae65df6d"}, { new Terminator(OperatorType.Minus), "621da7b6-7ffa-4f4b-90de-ba132492dd17"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c2f516c5-0d8f-4869-a661-2d6be33e865b") },
		{ "274d3e22-1ad4-4b9d-b505-f06936ee467e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "274d3e22-1ad4-4b9d-b505-f06936ee467e") },
		{ "c8fe07c7-cb87-4261-9ebd-63c550b677c5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "e788ed5c-6303-49fe-8332-381b90cdb5fc"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "c8fe07c7-cb87-4261-9ebd-63c550b677c5") },
		{ "1d5708e8-74c6-43aa-ae3d-3f7c50432ec9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "1d5708e8-74c6-43aa-ae3d-3f7c50432ec9") },
		{ "4e59346b-9d26-4777-b6ff-00c698fe6350", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "4e59346b-9d26-4777-b6ff-00c698fe6350") },
		{ "7839987b-51e5-4409-ac26-a85a45ec24ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "d529aa7f-227d-43e4-a176-33d7ea9b0aea"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7839987b-51e5-4409-ac26-a85a45ec24ec") },
		{ "1661d383-8c81-4120-a961-b9dce4b6e5ca", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "0892ba0d-bf5c-4a1a-add7-133a2422a272"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1661d383-8c81-4120-a961-b9dce4b6e5ca") },
		{ "4f83fa18-00b6-4e07-80f9-1a85637a5643", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "b7bbc256-dad1-446a-8340-550ee92ff0a7"}, { new NonTerminator(NonTerminatorType.Factor), "58f680fd-f914-4d3f-a9ed-fb60a1471402"}, { Terminator.NumberTerminator, "f930dc3a-6f4b-4027-8e2a-e90033cf368d"}, { new NonTerminator(NonTerminatorType.Variable), "76c719e8-1e4a-4b53-9642-55e160369cac"}, { new Terminator(DelimiterType.LeftParenthesis), "d6227fe3-5332-41f3-ab13-5057107bce10"}, { Terminator.IdentifierTerminator, "6052705e-8ab3-4feb-8695-54d74284ca66"}, { new Terminator(KeywordType.Not), "f376a735-da5f-4fe9-b205-29a7176e2c96"}, { new Terminator(OperatorType.Minus), "6ea108d2-4583-48c1-acee-c6829c953b48"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4f83fa18-00b6-4e07-80f9-1a85637a5643") },
		{ "bdf8765d-283f-41e7-966c-2a54a4b6afe4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "d86cda8b-4bd1-4c33-b83b-d2ded63f3050"}, { Terminator.NumberTerminator, "f930dc3a-6f4b-4027-8e2a-e90033cf368d"}, { new NonTerminator(NonTerminatorType.Variable), "76c719e8-1e4a-4b53-9642-55e160369cac"}, { new Terminator(DelimiterType.LeftParenthesis), "d6227fe3-5332-41f3-ab13-5057107bce10"}, { Terminator.IdentifierTerminator, "6052705e-8ab3-4feb-8695-54d74284ca66"}, { new Terminator(KeywordType.Not), "f376a735-da5f-4fe9-b205-29a7176e2c96"}, { new Terminator(OperatorType.Minus), "6ea108d2-4583-48c1-acee-c6829c953b48"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bdf8765d-283f-41e7-966c-2a54a4b6afe4") },
		{ "1f2ea4f7-0ffb-4854-a0a3-3c2f97d9747f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "d5708e0b-700e-4e83-adc2-bee0b70eafc3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1f2ea4f7-0ffb-4854-a0a3-3c2f97d9747f") },
		{ "62026db8-4d12-451a-93c8-4fbf3b11877b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "dffb785a-cbb7-4afc-971f-a161b87da663"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "62026db8-4d12-451a-93c8-4fbf3b11877b") },
		{ "afe9f26c-35f4-4ce1-b79f-3970a0335675", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "afe9f26c-35f4-4ce1-b79f-3970a0335675") },
		{ "7c05d619-5dbc-4015-995e-b1df5b1d8850", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "1618b3cd-c323-4871-9ef0-66247e7e1d0e"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7c05d619-5dbc-4015-995e-b1df5b1d8850") },
		{ "87f426a2-508c-447a-bc79-5c945c4b9608", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "87f426a2-508c-447a-bc79-5c945c4b9608") },
		{ "9a641d8a-27bf-412f-83b5-8347f0a8d5e6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "9a641d8a-27bf-412f-83b5-8347f0a8d5e6") },
		{ "baccb7b7-a262-445d-9f01-35dad91786cb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "baccb7b7-a262-445d-9f01-35dad91786cb") },
		{ "382a159f-2ba9-4c57-92db-d473b1e713b1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "382a159f-2ba9-4c57-92db-d473b1e713b1") },
		{ "b6764215-970e-4c4e-b623-a915a5440e57", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "a7922dc4-192b-4a7b-af3f-079a193b8bba"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b6764215-970e-4c4e-b623-a915a5440e57") },
		{ "6baf1069-e017-49f8-bc03-41493e396198", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "b5f4fdaa-f157-43ae-9ab6-268a1beb40a5"}, { new Terminator(OperatorType.Equal), "e60f0a44-0071-48cd-9938-5e1f4ebc1750"}, { new Terminator(OperatorType.NotEqual), "bff81bfb-5d76-4d37-ac47-0f8131be9179"}, { new Terminator(OperatorType.Less), "b74c6061-fc5a-421c-b2ba-b08541ad104b"}, { new Terminator(OperatorType.LessEqual), "a1dc7077-7d4e-49a2-9b3f-eb7a1e50f7a3"}, { new Terminator(OperatorType.Greater), "df1da848-76b4-4f80-8032-2c5f6b51d257"}, { new Terminator(OperatorType.GreaterEqual), "d41fbe91-c8fc-4777-8ae9-153d60b07a0a"}, { new NonTerminator(NonTerminatorType.AddOperator), "aeccf153-6341-49f7-8b5e-f18556538b92"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "6baf1069-e017-49f8-bc03-41493e396198") },
		{ "77edd341-4912-4ec6-9683-0e8edd08e541", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "12dcce56-83e0-45f7-a3ed-12c8f1510f0f"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "77edd341-4912-4ec6-9683-0e8edd08e541") },
		{ "7eb5aa71-c08f-422a-8d32-5364d19d69fb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "7eb5aa71-c08f-422a-8d32-5364d19d69fb") },
		{ "3c97d09d-1254-472d-b345-f497633b0b0e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "3c97d09d-1254-472d-b345-f497633b0b0e") },
		{ "699a5d91-d3c2-4cea-b907-f4a335dba5bd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "699a5d91-d3c2-4cea-b907-f4a335dba5bd") },
		{ "ffd3ed53-837c-46a1-86c3-2e75bf9405b6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "cb2e1fbe-121b-43ea-9481-fa8bce4a8f31"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ffd3ed53-837c-46a1-86c3-2e75bf9405b6") },
		{ "054e7a0d-4bed-417e-846e-9d1a5525d3c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "06c560d8-18c0-4c3b-9310-0247f7d2931a"}, { new NonTerminator(NonTerminatorType.IdVarPart), "14512a87-503c-49e7-9b73-40330970d6d6"}, { new Terminator(DelimiterType.LeftSquareBracket), "7f4593b0-31df-42dc-a652-8b902ce8c262"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "054e7a0d-4bed-417e-846e-9d1a5525d3c2") },
		{ "cc5884b4-7229-492f-a0e3-cbfdbe1bc959", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "a89e06b6-7c38-4a89-829c-ffb2d41e95b1"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cc5884b4-7229-492f-a0e3-cbfdbe1bc959") },
		{ "176c52d3-eaa0-4523-b746-e6612e9b2b3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "90b0d682-2b3e-4f9f-8c19-087e71945f67"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "176c52d3-eaa0-4523-b746-e6612e9b2b3b") },
		{ "e46438e1-766f-4d06-b6d1-a67442d27824", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "ea6d53ca-660e-42c1-993c-3fbcf5ca8375"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "e46438e1-766f-4d06-b6d1-a67442d27824") },
		{ "b218f401-dff9-4968-b9d1-a7eb4deabdd6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "191bdcdc-c2c3-484c-9d73-70ea288d0d92"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b218f401-dff9-4968-b9d1-a7eb4deabdd6") },
		{ "d638731c-5d03-477c-a0a6-93f866022f1c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "d638731c-5d03-477c-a0a6-93f866022f1c") },
		{ "979daaa7-74d6-437e-a947-0484c4e6f9e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "979daaa7-74d6-437e-a947-0484c4e6f9e9") },
		{ "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8") },
		{ "3fcf844f-0051-4f12-8247-561b25885410", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "3999563e-b92e-48ad-9588-3d6461c1f30f"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3fcf844f-0051-4f12-8247-561b25885410") },
		{ "07babfee-20d5-4a84-b812-4f030a7ec54d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "c6a1e86b-f0fe-4941-9f94-950e97e23df5"}, { new NonTerminator(NonTerminatorType.IdVarPart), "e5f8b868-5f6c-4a52-9fcc-268434356c5a"}, { new Terminator(DelimiterType.LeftSquareBracket), "6bf61759-af2c-47df-9da4-edee651b327a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "07babfee-20d5-4a84-b812-4f030a7ec54d") },
		{ "4022df3b-2f23-483c-841b-8a0211dc57e7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2dba6ddd-ee31-4d6d-a8b7-98d6bd84d912"}, { Terminator.NumberTerminator, "979daaa7-74d6-437e-a947-0484c4e6f9e9"}, { new NonTerminator(NonTerminatorType.Variable), "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8"}, { new Terminator(DelimiterType.LeftParenthesis), "3fcf844f-0051-4f12-8247-561b25885410"}, { Terminator.IdentifierTerminator, "07babfee-20d5-4a84-b812-4f030a7ec54d"}, { new Terminator(KeywordType.Not), "4022df3b-2f23-483c-841b-8a0211dc57e7"}, { new Terminator(OperatorType.Minus), "0270f9d3-5591-47f2-8108-c2cf69bdb734"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4022df3b-2f23-483c-841b-8a0211dc57e7") },
		{ "0270f9d3-5591-47f2-8108-c2cf69bdb734", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "80a3f0ed-ce07-46df-8de3-527fcd1be869"}, { Terminator.NumberTerminator, "979daaa7-74d6-437e-a947-0484c4e6f9e9"}, { new NonTerminator(NonTerminatorType.Variable), "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8"}, { new Terminator(DelimiterType.LeftParenthesis), "3fcf844f-0051-4f12-8247-561b25885410"}, { Terminator.IdentifierTerminator, "07babfee-20d5-4a84-b812-4f030a7ec54d"}, { new Terminator(KeywordType.Not), "4022df3b-2f23-483c-841b-8a0211dc57e7"}, { new Terminator(OperatorType.Minus), "0270f9d3-5591-47f2-8108-c2cf69bdb734"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0270f9d3-5591-47f2-8108-c2cf69bdb734") },
		{ "81dbd81e-9dee-449f-8236-b4b7951cacb6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "82e7ffa4-640c-4413-b8cb-3072c4389f33"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "81dbd81e-9dee-449f-8236-b4b7951cacb6") },
		{ "6d232c84-78b1-4eb1-b87c-0419274c2ac2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "6d232c84-78b1-4eb1-b87c-0419274c2ac2") },
		{ "12a6fb19-d41c-426b-8526-4e6036f352f6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "12a6fb19-d41c-426b-8526-4e6036f352f6") },
		{ "91d186ef-da4e-4cef-8640-6df487c1b092", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "541b7aed-6f60-4f43-87a0-f89ce681fbff"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "91d186ef-da4e-4cef-8640-6df487c1b092") },
		{ "646c0a5f-80b7-4a7a-b94b-cf27267b2e46", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "72cec223-9b9c-4155-ab18-266b9563c86f"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "646c0a5f-80b7-4a7a-b94b-cf27267b2e46") },
		{ "619c6f1e-1f7c-408b-9632-3b7ac8942358", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "619c6f1e-1f7c-408b-9632-3b7ac8942358") },
		{ "ae7dc6e3-edcf-4492-85c8-9354c0d37049", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(6, new NonTerminator(NonTerminatorType.Type))}, }, "ae7dc6e3-edcf-4492-85c8-9354c0d37049") },
		{ "2dbfcd41-8fcb-42fe-b259-890e488861c1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "22e378df-181b-4ba0-8b39-ee466ac3261c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2dbfcd41-8fcb-42fe-b259-890e488861c1") },
		{ "2365ec70-6eba-4014-8011-295bf3b64670", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "c8850e4a-5fa5-471f-ae33-bc1922e35682"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2365ec70-6eba-4014-8011-295bf3b64670") },
		{ "8784ad51-d3fa-40d4-a867-d9a66f959e93", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "8784ad51-d3fa-40d4-a867-d9a66f959e93") },
		{ "c0b61b00-2687-40dd-9052-527ead30bc36", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "c0b61b00-2687-40dd-9052-527ead30bc36") },
		{ "43fe5aa6-297d-40b5-bf42-67113c0ec3af", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "44db8192-f1d4-4c52-a727-f193e5b6ef24"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "43fe5aa6-297d-40b5-bf42-67113c0ec3af") },
		{ "f10c735b-c152-4f1a-826c-2feceb2174ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "7eee80c6-a41e-4349-8490-c670d828b516"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f10c735b-c152-4f1a-826c-2feceb2174ec") },
		{ "30434d67-0dd0-40b0-95c8-b158d6b5c266", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "46aba7d9-17a1-43bc-975f-75b066d23bc7"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "30434d67-0dd0-40b0-95c8-b158d6b5c266") },
		{ "5fa3bfe5-e519-4fa2-9604-943f1b5761c6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "5fa3bfe5-e519-4fa2-9604-943f1b5761c6") },
		{ "347f8aa8-8d3b-4ec5-9480-d51368a59a58", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "347f8aa8-8d3b-4ec5-9480-d51368a59a58") },
		{ "233b5bc9-6e08-440e-bfd1-cb4711b50495", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "c48d9f73-7af8-4382-b32c-7053b53b7604"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "233b5bc9-6e08-440e-bfd1-cb4711b50495") },
		{ "f445ed10-a97b-48d7-87ce-e7b56123fb64", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "b556e148-e40e-416a-ac8e-2ecae8770d20"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f445ed10-a97b-48d7-87ce-e7b56123fb64") },
		{ "467aab78-6373-405c-97e0-3943501ef0b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d006983d-4992-4977-b35a-409be1bd8de6"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "467aab78-6373-405c-97e0-3943501ef0b9") },
		{ "fba2fbb1-b310-40f5-b069-991fa81e31c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "fba2fbb1-b310-40f5-b069-991fa81e31c0") },
		{ "3514bf8a-669e-4b39-9124-830aacfa113a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "3514bf8a-669e-4b39-9124-830aacfa113a") },
		{ "dc06b371-cb33-4979-a436-fe879811593f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8f84c8da-680e-483e-a1b7-288b033389b4"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dc06b371-cb33-4979-a436-fe879811593f") },
		{ "24d96ade-bcaf-49fd-9386-d8143675db95", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "d0f054ce-5b0d-4f4c-a3e5-216e3d46bbc1"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "24d96ade-bcaf-49fd-9386-d8143675db95") },
		{ "12ca8229-7472-443a-92d0-7271a9bfbe07", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "1cc925ed-114d-4435-87ce-381babdf5cd3"}, { new NonTerminator(NonTerminatorType.Term), "94040141-ae6e-4c9f-8976-32fb4c2f6e6e"}, { new NonTerminator(NonTerminatorType.Factor), "27f7e48d-9ca9-49df-b5f4-0a959c347f81"}, { Terminator.NumberTerminator, "6dfe1629-75c8-4a5f-ae25-cb700f06497a"}, { new NonTerminator(NonTerminatorType.Variable), "6a4843f5-68fc-435f-88e0-0c8b42beb220"}, { new Terminator(DelimiterType.LeftParenthesis), "d3ee5519-8122-435e-bda9-6c391082b86b"}, { Terminator.IdentifierTerminator, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086"}, { new Terminator(KeywordType.Not), "a41f2fad-acca-4456-86d0-664a05435c9e"}, { new Terminator(OperatorType.Minus), "1ddaf31e-6264-4606-9bf2-40f2e22b9222"},}, new Dictionary<Terminator, ReduceInformation>{ }, "12ca8229-7472-443a-92d0-7271a9bfbe07") },
		{ "35bfc9e2-4796-4be8-82b9-d04d62aa91aa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "6c260f5a-2277-4259-aac4-a6b362e2dc2e"}, { new NonTerminator(NonTerminatorType.Factor), "12d20e8a-78e0-43f4-8830-e6a0e7af4c21"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "35bfc9e2-4796-4be8-82b9-d04d62aa91aa") },
		{ "738a8ae5-c9ba-4a05-b4f8-3bb7fa5cab72", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "655ecb86-4fbe-4690-8545-89deb8b60368"}, { Terminator.NumberTerminator, "57590ab0-600a-45be-82f5-329e29ea00e3"}, { new NonTerminator(NonTerminatorType.Variable), "7d99968e-f678-475d-9161-34566f505e53"}, { new Terminator(DelimiterType.LeftParenthesis), "7aac5197-8c61-408d-a62b-911e7ad47adf"}, { Terminator.IdentifierTerminator, "bd6d4b98-725a-4ba1-ac88-757e5832e3d0"}, { new Terminator(KeywordType.Not), "fdef1166-94b0-4796-bc24-30c6a09a5277"}, { new Terminator(OperatorType.Minus), "b5f3035f-427c-4c1c-b77b-752608a50215"},}, new Dictionary<Terminator, ReduceInformation>{ }, "738a8ae5-c9ba-4a05-b4f8-3bb7fa5cab72") },
		{ "a18441aa-def0-4be9-8f95-149515799004", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "c38cced1-cb14-4d26-b29c-338002e0d6de"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a18441aa-def0-4be9-8f95-149515799004") },
		{ "6e247029-5710-4182-a5ec-ef2797656e2e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "4b3f7420-89bb-4d17-a2fa-4c928cd436c7"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6e247029-5710-4182-a5ec-ef2797656e2e") },
		{ "96416a71-2054-458b-b4c6-28991c3e33ea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "96416a71-2054-458b-b4c6-28991c3e33ea") },
		{ "5bcba7e7-ce11-44d3-a0cc-566333ae1554", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8ea7cec4-b362-434e-8ab0-47fe6efed57c"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5bcba7e7-ce11-44d3-a0cc-566333ae1554") },
		{ "77d4b6a0-72ec-44c5-8772-886454b803aa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "77d4b6a0-72ec-44c5-8772-886454b803aa") },
		{ "0fdb49b0-be6a-4b0a-80cd-ad8a192879c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "0fdb49b0-be6a-4b0a-80cd-ad8a192879c0") },
		{ "d64dfbf1-cbbc-4e8c-a678-284de76d2413", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "d64dfbf1-cbbc-4e8c-a678-284de76d2413") },
		{ "de0fd8e5-8027-4d7d-be8a-ce62a8e1c512", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "e48b46b6-b509-48b6-87e8-642a3f32afcd"}, { new Terminator(KeywordType.Else), "e7fd2366-6bfd-4adf-8c5c-6402f9525eea"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "de0fd8e5-8027-4d7d-be8a-ce62a8e1c512") },
		{ "6ada1aba-a74f-4f76-87ba-f74f4ae26be2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "92923031-e040-46b2-a035-8e2913f62c68"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6ada1aba-a74f-4f76-87ba-f74f4ae26be2") },
		{ "d529aa7f-227d-43e4-a176-33d7ea9b0aea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "d529aa7f-227d-43e4-a176-33d7ea9b0aea") },
		{ "0892ba0d-bf5c-4a1a-add7-133a2422a272", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "0892ba0d-bf5c-4a1a-add7-133a2422a272") },
		{ "b7bbc256-dad1-446a-8340-550ee92ff0a7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "bdf8765d-283f-41e7-966c-2a54a4b6afe4"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b7bbc256-dad1-446a-8340-550ee92ff0a7") },
		{ "d86cda8b-4bd1-4c33-b83b-d2ded63f3050", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "d86cda8b-4bd1-4c33-b83b-d2ded63f3050") },
		{ "d5708e0b-700e-4e83-adc2-bee0b70eafc3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "d5708e0b-700e-4e83-adc2-bee0b70eafc3") },
		{ "dffb785a-cbb7-4afc-971f-a161b87da663", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "58680f63-2227-45aa-8d14-48abe0ed5198"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dffb785a-cbb7-4afc-971f-a161b87da663") },
		{ "1618b3cd-c323-4871-9ef0-66247e7e1d0e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "c108cc98-d6e7-4d6e-8112-4f143c08cc88"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1618b3cd-c323-4871-9ef0-66247e7e1d0e") },
		{ "a7922dc4-192b-4a7b-af3f-079a193b8bba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "e0108ddc-d650-4dd2-920f-aa3799c9eacb"}, { new NonTerminator(NonTerminatorType.Variable), "0917a51c-0f6b-4995-9b71-a70bfae21876"}, { Terminator.IdentifierTerminator, "d6aa7d6a-3de5-40c0-8676-31a5db27f2b0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "4abbc50c-c8c4-4d30-9cc7-d95432a4e52a"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7f34a249-48c2-43b5-ad57-2c6ce9d6fccc"}, { new Terminator(KeywordType.If), "4ced18e3-005a-425d-93ff-95f555f6c0b0"}, { new Terminator(KeywordType.For), "06bd10fc-30bb-44eb-aa64-356c9ce074ee"}, { new Terminator(KeywordType.Begin), "2718db4f-527a-418c-9c29-cc188ac8ff73"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "a7922dc4-192b-4a7b-af3f-079a193b8bba") },
		{ "b5f4fdaa-f157-43ae-9ab6-268a1beb40a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "8489f1a9-e95a-4c93-8ce5-7c3af11aaf6d"}, { new NonTerminator(NonTerminatorType.Term), "90256c5f-a0a3-4cd7-8df1-5949c64f3180"}, { new NonTerminator(NonTerminatorType.Factor), "ce206feb-163e-4a1c-b56c-36fa82373c74"}, { Terminator.NumberTerminator, "05112924-c098-4441-bd00-bce7100c0e71"}, { new NonTerminator(NonTerminatorType.Variable), "a9597b42-7356-4625-b2ad-2b6a9f13626b"}, { new Terminator(DelimiterType.LeftParenthesis), "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8"}, { Terminator.IdentifierTerminator, "54fac68e-82e5-4339-891f-5bd6299f693f"}, { new Terminator(KeywordType.Not), "b7780951-572b-4e41-b43a-ce70bd3cde38"}, { new Terminator(OperatorType.Minus), "7a7eac0f-e5a8-4e30-9b91-eae66737be67"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b5f4fdaa-f157-43ae-9ab6-268a1beb40a5") },
		{ "aeccf153-6341-49f7-8b5e-f18556538b92", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "9cfb6b6e-883d-4b4a-8a83-e6b43c18ff3b"}, { new NonTerminator(NonTerminatorType.Factor), "7eb5aa71-c08f-422a-8d32-5364d19d69fb"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "aeccf153-6341-49f7-8b5e-f18556538b92") },
		{ "12dcce56-83e0-45f7-a3ed-12c8f1510f0f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f3803bd6-8715-4a69-8d11-0e5a4b950456"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "12dcce56-83e0-45f7-a3ed-12c8f1510f0f") },
		{ "cb2e1fbe-121b-43ea-9481-fa8bce4a8f31", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "168cb92b-5d7f-4dc8-9124-c5e8531346ec"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cb2e1fbe-121b-43ea-9481-fa8bce4a8f31") },
		{ "06c560d8-18c0-4c3b-9310-0247f7d2931a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "3cfa2a73-702a-4d49-a707-10822139bf83"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "06c560d8-18c0-4c3b-9310-0247f7d2931a") },
		{ "14512a87-503c-49e7-9b73-40330970d6d6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "14512a87-503c-49e7-9b73-40330970d6d6") },
		{ "7f4593b0-31df-42dc-a652-8b902ce8c262", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "64bc1190-bf0e-4658-bca9-908b9906215b"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7f4593b0-31df-42dc-a652-8b902ce8c262") },
		{ "a89e06b6-7c38-4a89-829c-ffb2d41e95b1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "a89e06b6-7c38-4a89-829c-ffb2d41e95b1") },
		{ "90b0d682-2b3e-4f9f-8c19-087e71945f67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "90b0d682-2b3e-4f9f-8c19-087e71945f67") },
		{ "ea6d53ca-660e-42c1-993c-3fbcf5ca8375", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "7cb5c42e-c20e-4809-9ea3-cccee5eab375"}, { new NonTerminator(NonTerminatorType.Factor), "d638731c-5d03-477c-a0a6-93f866022f1c"}, { Terminator.NumberTerminator, "979daaa7-74d6-437e-a947-0484c4e6f9e9"}, { new NonTerminator(NonTerminatorType.Variable), "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8"}, { new Terminator(DelimiterType.LeftParenthesis), "3fcf844f-0051-4f12-8247-561b25885410"}, { Terminator.IdentifierTerminator, "07babfee-20d5-4a84-b812-4f030a7ec54d"}, { new Terminator(KeywordType.Not), "4022df3b-2f23-483c-841b-8a0211dc57e7"}, { new Terminator(OperatorType.Minus), "0270f9d3-5591-47f2-8108-c2cf69bdb734"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ea6d53ca-660e-42c1-993c-3fbcf5ca8375") },
		{ "191bdcdc-c2c3-484c-9d73-70ea288d0d92", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "13fc3c61-f00b-4de6-bcb2-556270a78ffc"}, { Terminator.NumberTerminator, "979daaa7-74d6-437e-a947-0484c4e6f9e9"}, { new NonTerminator(NonTerminatorType.Variable), "4c3caff3-f82a-4f8f-aeb9-b2a19021d3b8"}, { new Terminator(DelimiterType.LeftParenthesis), "3fcf844f-0051-4f12-8247-561b25885410"}, { Terminator.IdentifierTerminator, "07babfee-20d5-4a84-b812-4f030a7ec54d"}, { new Terminator(KeywordType.Not), "4022df3b-2f23-483c-841b-8a0211dc57e7"}, { new Terminator(OperatorType.Minus), "0270f9d3-5591-47f2-8108-c2cf69bdb734"},}, new Dictionary<Terminator, ReduceInformation>{ }, "191bdcdc-c2c3-484c-9d73-70ea288d0d92") },
		{ "3999563e-b92e-48ad-9588-3d6461c1f30f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4d2650d8-f247-4634-97de-b7f56c95d4d7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3999563e-b92e-48ad-9588-3d6461c1f30f") },
		{ "c6a1e86b-f0fe-4941-9f94-950e97e23df5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "d931184d-85b4-4fec-bf82-1daa3fd7950e"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c6a1e86b-f0fe-4941-9f94-950e97e23df5") },
		{ "e5f8b868-5f6c-4a52-9fcc-268434356c5a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "e5f8b868-5f6c-4a52-9fcc-268434356c5a") },
		{ "6bf61759-af2c-47df-9da4-edee651b327a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8fe786a0-6138-4079-8f93-5a14baaf5f4b"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6bf61759-af2c-47df-9da4-edee651b327a") },
		{ "2dba6ddd-ee31-4d6d-a8b7-98d6bd84d912", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "2dba6ddd-ee31-4d6d-a8b7-98d6bd84d912") },
		{ "80a3f0ed-ce07-46df-8de3-527fcd1be869", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "80a3f0ed-ce07-46df-8de3-527fcd1be869") },
		{ "541b7aed-6f60-4f43-87a0-f89ce681fbff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "541b7aed-6f60-4f43-87a0-f89ce681fbff") },
		{ "72cec223-9b9c-4155-ab18-266b9563c86f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "72cec223-9b9c-4155-ab18-266b9563c86f") },
		{ "22e378df-181b-4ba0-8b39-ee466ac3261c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, }, "22e378df-181b-4ba0-8b39-ee466ac3261c") },
		{ "44db8192-f1d4-4c52-a727-f193e5b6ef24", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "44db8192-f1d4-4c52-a727-f193e5b6ef24") },
		{ "7eee80c6-a41e-4349-8490-c670d828b516", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "7eee80c6-a41e-4349-8490-c670d828b516") },
		{ "c48d9f73-7af8-4382-b32c-7053b53b7604", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "c48d9f73-7af8-4382-b32c-7053b53b7604") },
		{ "b556e148-e40e-416a-ac8e-2ecae8770d20", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "b556e148-e40e-416a-ac8e-2ecae8770d20") },
		{ "8f84c8da-680e-483e-a1b7-288b033389b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "8f84c8da-680e-483e-a1b7-288b033389b4") },
		{ "d0f054ce-5b0d-4f4c-a3e5-216e3d46bbc1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "d0f054ce-5b0d-4f4c-a3e5-216e3d46bbc1") },
		{ "1cc925ed-114d-4435-87ce-381babdf5cd3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "545234df-9801-4aed-9f7f-605fa8fb00ce"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "1cc925ed-114d-4435-87ce-381babdf5cd3") },
		{ "94040141-ae6e-4c9f-8976-32fb4c2f6e6e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "eb0c4da4-d71e-4edf-a7bd-0a92fc99c806"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "94040141-ae6e-4c9f-8976-32fb4c2f6e6e") },
		{ "27f7e48d-9ca9-49df-b5f4-0a959c347f81", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "27f7e48d-9ca9-49df-b5f4-0a959c347f81") },
		{ "6dfe1629-75c8-4a5f-ae25-cb700f06497a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6dfe1629-75c8-4a5f-ae25-cb700f06497a") },
		{ "6a4843f5-68fc-435f-88e0-0c8b42beb220", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6a4843f5-68fc-435f-88e0-0c8b42beb220") },
		{ "d3ee5519-8122-435e-bda9-6c391082b86b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "3fe40ab7-97b0-45dc-b86a-b02c6e5658d6"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d3ee5519-8122-435e-bda9-6c391082b86b") },
		{ "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "fbb1f39c-bc09-4e63-8e58-105efe4fb6e3"}, { new NonTerminator(NonTerminatorType.IdVarPart), "76a920a1-9cd0-4a01-9001-659ad520b167"}, { new Terminator(DelimiterType.LeftSquareBracket), "56aacd7c-dc1d-43cd-88f8-45db040299e9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086") },
		{ "a41f2fad-acca-4456-86d0-664a05435c9e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "d75a5fab-e8f5-4644-85d2-f576fde4c614"}, { Terminator.NumberTerminator, "6dfe1629-75c8-4a5f-ae25-cb700f06497a"}, { new NonTerminator(NonTerminatorType.Variable), "6a4843f5-68fc-435f-88e0-0c8b42beb220"}, { new Terminator(DelimiterType.LeftParenthesis), "d3ee5519-8122-435e-bda9-6c391082b86b"}, { Terminator.IdentifierTerminator, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086"}, { new Terminator(KeywordType.Not), "a41f2fad-acca-4456-86d0-664a05435c9e"}, { new Terminator(OperatorType.Minus), "1ddaf31e-6264-4606-9bf2-40f2e22b9222"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a41f2fad-acca-4456-86d0-664a05435c9e") },
		{ "1ddaf31e-6264-4606-9bf2-40f2e22b9222", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "6382e01d-df8d-4a84-9278-74a837b2ad8a"}, { Terminator.NumberTerminator, "6dfe1629-75c8-4a5f-ae25-cb700f06497a"}, { new NonTerminator(NonTerminatorType.Variable), "6a4843f5-68fc-435f-88e0-0c8b42beb220"}, { new Terminator(DelimiterType.LeftParenthesis), "d3ee5519-8122-435e-bda9-6c391082b86b"}, { Terminator.IdentifierTerminator, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086"}, { new Terminator(KeywordType.Not), "a41f2fad-acca-4456-86d0-664a05435c9e"}, { new Terminator(OperatorType.Minus), "1ddaf31e-6264-4606-9bf2-40f2e22b9222"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1ddaf31e-6264-4606-9bf2-40f2e22b9222") },
		{ "6c260f5a-2277-4259-aac4-a6b362e2dc2e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "738a8ae5-c9ba-4a05-b4f8-3bb7fa5cab72"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "6c260f5a-2277-4259-aac4-a6b362e2dc2e") },
		{ "655ecb86-4fbe-4690-8545-89deb8b60368", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "655ecb86-4fbe-4690-8545-89deb8b60368") },
		{ "c38cced1-cb14-4d26-b29c-338002e0d6de", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "c38cced1-cb14-4d26-b29c-338002e0d6de") },
		{ "4b3f7420-89bb-4d17-a2fa-4c928cd436c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4b6d2ddd-73a1-4aef-af65-1e0b590ee4b8"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4b3f7420-89bb-4d17-a2fa-4c928cd436c7") },
		{ "8ea7cec4-b362-434e-8ab0-47fe6efed57c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "bd6ab312-3437-4706-afe7-8d3881490f6c"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8ea7cec4-b362-434e-8ab0-47fe6efed57c") },
		{ "e48b46b6-b509-48b6-87e8-642a3f32afcd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "e48b46b6-b509-48b6-87e8-642a3f32afcd") },
		{ "e7fd2366-6bfd-4adf-8c5c-6402f9525eea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "474c599c-462b-4d30-8f4c-a49c15490a80"}, { new NonTerminator(NonTerminatorType.Variable), "b673a04f-5b49-48ea-b31a-e543bb450990"}, { Terminator.IdentifierTerminator, "a1d8212d-7a8c-487f-af11-a09b7a139999"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "d7769531-8722-4562-a86c-db01e53d2601"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "232955bf-eb89-4b2b-b0b2-2a2def84a012"}, { new Terminator(KeywordType.If), "53bcac81-472d-472c-ac1b-95ccd69eec62"}, { new Terminator(KeywordType.For), "343bc0df-a720-484c-a7ec-c3f13b014a7e"}, { new Terminator(KeywordType.Begin), "b81770c8-69fc-4aea-85f3-fdbd63baa29a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "e7fd2366-6bfd-4adf-8c5c-6402f9525eea") },
		{ "92923031-e040-46b2-a035-8e2913f62c68", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "72e7859c-3675-4305-b634-1f4a0393c650"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "6baf1069-e017-49f8-bc03-41493e396198"}, { new NonTerminator(NonTerminatorType.Term), "77edd341-4912-4ec6-9683-0e8edd08e541"}, { new NonTerminator(NonTerminatorType.Factor), "7eb5aa71-c08f-422a-8d32-5364d19d69fb"}, { Terminator.NumberTerminator, "3c97d09d-1254-472d-b345-f497633b0b0e"}, { new NonTerminator(NonTerminatorType.Variable), "699a5d91-d3c2-4cea-b907-f4a335dba5bd"}, { new Terminator(DelimiterType.LeftParenthesis), "ffd3ed53-837c-46a1-86c3-2e75bf9405b6"}, { Terminator.IdentifierTerminator, "054e7a0d-4bed-417e-846e-9d1a5525d3c2"}, { new Terminator(KeywordType.Not), "cc5884b4-7229-492f-a0e3-cbfdbe1bc959"}, { new Terminator(OperatorType.Minus), "176c52d3-eaa0-4523-b746-e6612e9b2b3b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "92923031-e040-46b2-a035-8e2913f62c68") },
		{ "58680f63-2227-45aa-8d14-48abe0ed5198", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "58680f63-2227-45aa-8d14-48abe0ed5198") },
		{ "c108cc98-d6e7-4d6e-8112-4f143c08cc88", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "c108cc98-d6e7-4d6e-8112-4f143c08cc88") },
		{ "e0108ddc-d650-4dd2-920f-aa3799c9eacb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "e0108ddc-d650-4dd2-920f-aa3799c9eacb") },
		{ "8489f1a9-e95a-4c93-8ce5-7c3af11aaf6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "3e0bbe09-fca5-400c-afe4-2f1d4173ef38"}, { new Terminator(OperatorType.Plus), "e1972b4b-6669-4585-b56e-954352b788bf"}, { new Terminator(OperatorType.Minus), "4fb07dba-bf26-4347-a306-1bb7ba903590"}, { new Terminator(KeywordType.Or), "0c2471fb-6af7-45bd-8a04-98ada7a266c7"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "8489f1a9-e95a-4c93-8ce5-7c3af11aaf6d") },
		{ "90256c5f-a0a3-4cd7-8df1-5949c64f3180", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d16d6411-f4b3-4624-9d15-4870835e8911"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "90256c5f-a0a3-4cd7-8df1-5949c64f3180") },
		{ "ce206feb-163e-4a1c-b56c-36fa82373c74", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "ce206feb-163e-4a1c-b56c-36fa82373c74") },
		{ "05112924-c098-4441-bd00-bce7100c0e71", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "05112924-c098-4441-bd00-bce7100c0e71") },
		{ "a9597b42-7356-4625-b2ad-2b6a9f13626b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a9597b42-7356-4625-b2ad-2b6a9f13626b") },
		{ "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "85ccd5a3-e89a-4264-b5cc-44a15796207c"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b3df006-7bad-45fc-8f6e-37150dd4a845"}, { new NonTerminator(NonTerminatorType.Term), "1c76a2a5-f5ba-485f-bea3-ee69def688d1"}, { new NonTerminator(NonTerminatorType.Factor), "f5b4dfe6-b493-4cf7-87f6-90a82667de84"}, { Terminator.NumberTerminator, "a7a80208-7348-4366-bc61-cac584c9e04a"}, { new NonTerminator(NonTerminatorType.Variable), "5ace0fc6-1154-458f-9dba-28b9f6160ce6"}, { new Terminator(DelimiterType.LeftParenthesis), "94c79094-9186-4861-a631-4dc359b90b39"}, { Terminator.IdentifierTerminator, "859c1708-4168-4083-a2de-7e704d473d03"}, { new Terminator(KeywordType.Not), "544263d9-48f5-4069-a3ea-0808185827ea"}, { new Terminator(OperatorType.Minus), "7492c66c-0393-4775-a03b-65a74bbbaba8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8") },
		{ "54fac68e-82e5-4339-891f-5bd6299f693f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "ed8fc472-f10a-40e4-8777-939ec516801c"}, { new NonTerminator(NonTerminatorType.IdVarPart), "0a60cfd6-cdfd-4022-b267-123e6eef82dd"}, { new Terminator(DelimiterType.LeftSquareBracket), "d3dc0a67-7311-438a-89c1-dc86e7ecef4d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "54fac68e-82e5-4339-891f-5bd6299f693f") },
		{ "b7780951-572b-4e41-b43a-ce70bd3cde38", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2c8df0ba-3444-447f-b957-a9d1f0cbe24c"}, { Terminator.NumberTerminator, "05112924-c098-4441-bd00-bce7100c0e71"}, { new NonTerminator(NonTerminatorType.Variable), "a9597b42-7356-4625-b2ad-2b6a9f13626b"}, { new Terminator(DelimiterType.LeftParenthesis), "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8"}, { Terminator.IdentifierTerminator, "54fac68e-82e5-4339-891f-5bd6299f693f"}, { new Terminator(KeywordType.Not), "b7780951-572b-4e41-b43a-ce70bd3cde38"}, { new Terminator(OperatorType.Minus), "7a7eac0f-e5a8-4e30-9b91-eae66737be67"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b7780951-572b-4e41-b43a-ce70bd3cde38") },
		{ "7a7eac0f-e5a8-4e30-9b91-eae66737be67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3220effd-9126-4e09-ae0d-2ab9b72a4a96"}, { Terminator.NumberTerminator, "05112924-c098-4441-bd00-bce7100c0e71"}, { new NonTerminator(NonTerminatorType.Variable), "a9597b42-7356-4625-b2ad-2b6a9f13626b"}, { new Terminator(DelimiterType.LeftParenthesis), "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8"}, { Terminator.IdentifierTerminator, "54fac68e-82e5-4339-891f-5bd6299f693f"}, { new Terminator(KeywordType.Not), "b7780951-572b-4e41-b43a-ce70bd3cde38"}, { new Terminator(OperatorType.Minus), "7a7eac0f-e5a8-4e30-9b91-eae66737be67"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7a7eac0f-e5a8-4e30-9b91-eae66737be67") },
		{ "9cfb6b6e-883d-4b4a-8a83-e6b43c18ff3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "12dcce56-83e0-45f7-a3ed-12c8f1510f0f"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "9cfb6b6e-883d-4b4a-8a83-e6b43c18ff3b") },
		{ "f3803bd6-8715-4a69-8d11-0e5a4b950456", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "f3803bd6-8715-4a69-8d11-0e5a4b950456") },
		{ "168cb92b-5d7f-4dc8-9124-c5e8531346ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "168cb92b-5d7f-4dc8-9124-c5e8531346ec") },
		{ "3cfa2a73-702a-4d49-a707-10822139bf83", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "56888c47-fe88-42d7-9f92-7c53994e0703"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3cfa2a73-702a-4d49-a707-10822139bf83") },
		{ "64bc1190-bf0e-4658-bca9-908b9906215b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "8c5d4408-fc07-4db7-94a5-b67ea0691d31"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "64bc1190-bf0e-4658-bca9-908b9906215b") },
		{ "7cb5c42e-c20e-4809-9ea3-cccee5eab375", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "191bdcdc-c2c3-484c-9d73-70ea288d0d92"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "7cb5c42e-c20e-4809-9ea3-cccee5eab375") },
		{ "13fc3c61-f00b-4de6-bcb2-556270a78ffc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "13fc3c61-f00b-4de6-bcb2-556270a78ffc") },
		{ "4d2650d8-f247-4634-97de-b7f56c95d4d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "4d2650d8-f247-4634-97de-b7f56c95d4d7") },
		{ "d931184d-85b4-4fec-bf82-1daa3fd7950e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a8a5c882-8aff-4a2d-b4e3-a01ecfc4e936"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d931184d-85b4-4fec-bf82-1daa3fd7950e") },
		{ "8fe786a0-6138-4079-8f93-5a14baaf5f4b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "37b52ce1-e7be-4944-9e0c-ccd8d7bc57a1"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8fe786a0-6138-4079-8f93-5a14baaf5f4b") },
		{ "545234df-9801-4aed-9f7f-605fa8fb00ce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "de1c4cf4-c907-41dd-a68f-91f651d1e6a1"}, { new NonTerminator(NonTerminatorType.Factor), "27f7e48d-9ca9-49df-b5f4-0a959c347f81"}, { Terminator.NumberTerminator, "6dfe1629-75c8-4a5f-ae25-cb700f06497a"}, { new NonTerminator(NonTerminatorType.Variable), "6a4843f5-68fc-435f-88e0-0c8b42beb220"}, { new Terminator(DelimiterType.LeftParenthesis), "d3ee5519-8122-435e-bda9-6c391082b86b"}, { Terminator.IdentifierTerminator, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086"}, { new Terminator(KeywordType.Not), "a41f2fad-acca-4456-86d0-664a05435c9e"}, { new Terminator(OperatorType.Minus), "1ddaf31e-6264-4606-9bf2-40f2e22b9222"},}, new Dictionary<Terminator, ReduceInformation>{ }, "545234df-9801-4aed-9f7f-605fa8fb00ce") },
		{ "eb0c4da4-d71e-4edf-a7bd-0a92fc99c806", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ba0ab91f-6e20-495f-bcf9-b56bfa7728dc"}, { Terminator.NumberTerminator, "6dfe1629-75c8-4a5f-ae25-cb700f06497a"}, { new NonTerminator(NonTerminatorType.Variable), "6a4843f5-68fc-435f-88e0-0c8b42beb220"}, { new Terminator(DelimiterType.LeftParenthesis), "d3ee5519-8122-435e-bda9-6c391082b86b"}, { Terminator.IdentifierTerminator, "5dbbcaa1-6c33-44e7-8b3f-9e3fa9e5d086"}, { new Terminator(KeywordType.Not), "a41f2fad-acca-4456-86d0-664a05435c9e"}, { new Terminator(OperatorType.Minus), "1ddaf31e-6264-4606-9bf2-40f2e22b9222"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eb0c4da4-d71e-4edf-a7bd-0a92fc99c806") },
		{ "3fe40ab7-97b0-45dc-b86a-b02c6e5658d6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "5ea7c89a-acba-4387-afaf-9ffda3105538"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3fe40ab7-97b0-45dc-b86a-b02c6e5658d6") },
		{ "fbb1f39c-bc09-4e63-8e58-105efe4fb6e3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8667ba87-1a32-4507-8962-5682bb89711f"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fbb1f39c-bc09-4e63-8e58-105efe4fb6e3") },
		{ "76a920a1-9cd0-4a01-9001-659ad520b167", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "76a920a1-9cd0-4a01-9001-659ad520b167") },
		{ "56aacd7c-dc1d-43cd-88f8-45db040299e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "d244b897-4ac5-4788-9509-c6af5041da90"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "56aacd7c-dc1d-43cd-88f8-45db040299e9") },
		{ "d75a5fab-e8f5-4644-85d2-f576fde4c614", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "d75a5fab-e8f5-4644-85d2-f576fde4c614") },
		{ "6382e01d-df8d-4a84-9278-74a837b2ad8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "6382e01d-df8d-4a84-9278-74a837b2ad8a") },
		{ "4b6d2ddd-73a1-4aef-af65-1e0b590ee4b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "4b6d2ddd-73a1-4aef-af65-1e0b590ee4b8") },
		{ "bd6ab312-3437-4706-afe7-8d3881490f6c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "bd6ab312-3437-4706-afe7-8d3881490f6c") },
		{ "474c599c-462b-4d30-8f4c-a49c15490a80", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "474c599c-462b-4d30-8f4c-a49c15490a80") },
		{ "72e7859c-3675-4305-b634-1f4a0393c650", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "700a772a-446c-4fa0-9ac1-c1572b53ed1d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "72e7859c-3675-4305-b634-1f4a0393c650") },
		{ "3e0bbe09-fca5-400c-afe4-2f1d4173ef38", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "ecde2a16-8655-4517-86e6-5b7a75b5d6c4"}, { new NonTerminator(NonTerminatorType.Factor), "ce206feb-163e-4a1c-b56c-36fa82373c74"}, { Terminator.NumberTerminator, "05112924-c098-4441-bd00-bce7100c0e71"}, { new NonTerminator(NonTerminatorType.Variable), "a9597b42-7356-4625-b2ad-2b6a9f13626b"}, { new Terminator(DelimiterType.LeftParenthesis), "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8"}, { Terminator.IdentifierTerminator, "54fac68e-82e5-4339-891f-5bd6299f693f"}, { new Terminator(KeywordType.Not), "b7780951-572b-4e41-b43a-ce70bd3cde38"}, { new Terminator(OperatorType.Minus), "7a7eac0f-e5a8-4e30-9b91-eae66737be67"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3e0bbe09-fca5-400c-afe4-2f1d4173ef38") },
		{ "d16d6411-f4b3-4624-9d15-4870835e8911", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3082bd9a-b914-460f-ac66-8807d62ce591"}, { Terminator.NumberTerminator, "05112924-c098-4441-bd00-bce7100c0e71"}, { new NonTerminator(NonTerminatorType.Variable), "a9597b42-7356-4625-b2ad-2b6a9f13626b"}, { new Terminator(DelimiterType.LeftParenthesis), "0c76cee1-97b5-4bd7-b68c-7c83c7bb5ee8"}, { Terminator.IdentifierTerminator, "54fac68e-82e5-4339-891f-5bd6299f693f"}, { new Terminator(KeywordType.Not), "b7780951-572b-4e41-b43a-ce70bd3cde38"}, { new Terminator(OperatorType.Minus), "7a7eac0f-e5a8-4e30-9b91-eae66737be67"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d16d6411-f4b3-4624-9d15-4870835e8911") },
		{ "85ccd5a3-e89a-4264-b5cc-44a15796207c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "b64e7252-525c-490c-9189-6a9cd78345cc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "85ccd5a3-e89a-4264-b5cc-44a15796207c") },
		{ "ed8fc472-f10a-40e4-8777-939ec516801c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "545f9092-a105-4e91-ab67-98bfa90db6bd"}, { new NonTerminator(NonTerminatorType.Expression), "4deb0928-e0b2-46ad-b36d-6db5892538d3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5c8951f9-34e6-4f48-ba21-c9d794f68704"}, { new NonTerminator(NonTerminatorType.Term), "b5dff012-7224-404c-be00-e05d8ecddad8"}, { new NonTerminator(NonTerminatorType.Factor), "cd7425f7-d1ab-4718-9b02-2736198de4ee"}, { Terminator.NumberTerminator, "82d93635-2453-4516-acc4-24c86c98ac12"}, { new NonTerminator(NonTerminatorType.Variable), "71eda53f-2674-4c70-aa3b-88ba5fe22e84"}, { new Terminator(DelimiterType.LeftParenthesis), "d54afc8c-616a-4817-8f09-a030d5f9cafc"}, { Terminator.IdentifierTerminator, "830c5311-98d9-4b2e-bbb8-dc489f2e47a8"}, { new Terminator(KeywordType.Not), "a78fbe54-cc31-4fdf-a7ec-5c6c7e338446"}, { new Terminator(OperatorType.Minus), "041ba0db-1aec-4fb5-ab79-e036dc670fc7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ed8fc472-f10a-40e4-8777-939ec516801c") },
		{ "0a60cfd6-cdfd-4022-b267-123e6eef82dd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "0a60cfd6-cdfd-4022-b267-123e6eef82dd") },
		{ "d3dc0a67-7311-438a-89c1-dc86e7ecef4d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2ca84969-59a0-4f6e-9a29-c771f5540416"}, { new NonTerminator(NonTerminatorType.Expression), "60377190-18c7-4991-b320-4fd8443987bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "08ecf76a-ceed-46ea-ac03-444efc640a89"}, { new NonTerminator(NonTerminatorType.Term), "288abaa4-40f6-4d16-b023-96815851dc13"}, { new NonTerminator(NonTerminatorType.Factor), "b0107e15-0526-414e-a98f-dfefdb6e55cd"}, { Terminator.NumberTerminator, "bf99b129-0c44-445f-880d-bf9e6106cf77"}, { new NonTerminator(NonTerminatorType.Variable), "6ecab451-234e-4f30-b34a-444ced34e95f"}, { new Terminator(DelimiterType.LeftParenthesis), "973a3492-2749-48fd-b226-4a224615f310"}, { Terminator.IdentifierTerminator, "ef53ba15-d58e-42d8-8e7a-496a78662e7e"}, { new Terminator(KeywordType.Not), "30f9f334-028f-4c9e-8fa7-d00e71c02f7a"}, { new Terminator(OperatorType.Minus), "43bfef6e-27a6-4ed5-9181-944c0c0869db"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d3dc0a67-7311-438a-89c1-dc86e7ecef4d") },
		{ "2c8df0ba-3444-447f-b957-a9d1f0cbe24c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "2c8df0ba-3444-447f-b957-a9d1f0cbe24c") },
		{ "3220effd-9126-4e09-ae0d-2ab9b72a4a96", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3220effd-9126-4e09-ae0d-2ab9b72a4a96") },
		{ "56888c47-fe88-42d7-9f92-7c53994e0703", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "56888c47-fe88-42d7-9f92-7c53994e0703") },
		{ "8c5d4408-fc07-4db7-94a5-b67ea0691d31", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "8c5d4408-fc07-4db7-94a5-b67ea0691d31") },
		{ "a8a5c882-8aff-4a2d-b4e3-a01ecfc4e936", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "a8a5c882-8aff-4a2d-b4e3-a01ecfc4e936") },
		{ "37b52ce1-e7be-4944-9e0c-ccd8d7bc57a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "37b52ce1-e7be-4944-9e0c-ccd8d7bc57a1") },
		{ "de1c4cf4-c907-41dd-a68f-91f651d1e6a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "eb0c4da4-d71e-4edf-a7bd-0a92fc99c806"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "de1c4cf4-c907-41dd-a68f-91f651d1e6a1") },
		{ "ba0ab91f-6e20-495f-bcf9-b56bfa7728dc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "ba0ab91f-6e20-495f-bcf9-b56bfa7728dc") },
		{ "5ea7c89a-acba-4387-afaf-9ffda3105538", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "5ea7c89a-acba-4387-afaf-9ffda3105538") },
		{ "8667ba87-1a32-4507-8962-5682bb89711f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "1caa9bbf-9279-442a-9fc0-26297d62e89b"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8667ba87-1a32-4507-8962-5682bb89711f") },
		{ "d244b897-4ac5-4788-9509-c6af5041da90", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "ccdb46a7-5133-4d62-bfd3-00a2593312f2"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d244b897-4ac5-4788-9509-c6af5041da90") },
		{ "700a772a-446c-4fa0-9ac1-c1572b53ed1d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "f887e062-3db6-4e36-9d96-7a26300d807c"}, { new NonTerminator(NonTerminatorType.Variable), "b673a04f-5b49-48ea-b31a-e543bb450990"}, { Terminator.IdentifierTerminator, "a1d8212d-7a8c-487f-af11-a09b7a139999"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "d7769531-8722-4562-a86c-db01e53d2601"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "232955bf-eb89-4b2b-b0b2-2a2def84a012"}, { new Terminator(KeywordType.If), "53bcac81-472d-472c-ac1b-95ccd69eec62"}, { new Terminator(KeywordType.For), "343bc0df-a720-484c-a7ec-c3f13b014a7e"}, { new Terminator(KeywordType.Begin), "b81770c8-69fc-4aea-85f3-fdbd63baa29a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "700a772a-446c-4fa0-9ac1-c1572b53ed1d") },
		{ "ecde2a16-8655-4517-86e6-5b7a75b5d6c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d16d6411-f4b3-4624-9d15-4870835e8911"}, { new Terminator(OperatorType.Multiply), "6920b693-65be-42ae-ac8b-33b45029671c"}, { new Terminator(OperatorType.Divide), "6d2a3b1a-5afd-463a-a8d0-0a0dc109eaaa"}, { new Terminator(KeywordType.Divide), "d63dc45c-9909-4e6d-bb6c-46feb9e31fb1"}, { new Terminator(KeywordType.Mod), "38a02d24-b6a3-44ee-8a9c-ee71205f82ed"}, { new Terminator(KeywordType.And), "2882f7ca-a974-4527-a642-468bc3be3037"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ecde2a16-8655-4517-86e6-5b7a75b5d6c4") },
		{ "3082bd9a-b914-460f-ac66-8807d62ce591", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "3082bd9a-b914-460f-ac66-8807d62ce591") },
		{ "b64e7252-525c-490c-9189-6a9cd78345cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "b64e7252-525c-490c-9189-6a9cd78345cc") },
		{ "545f9092-a105-4e91-ab67-98bfa90db6bd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "644fc401-94d3-470d-a388-a646ce973dc0"}, { new Terminator(DelimiterType.Comma), "cf5b6a68-58b4-43b0-88fe-e15516e737be"},}, new Dictionary<Terminator, ReduceInformation>{ }, "545f9092-a105-4e91-ab67-98bfa90db6bd") },
		{ "2ca84969-59a0-4f6e-9a29-c771f5540416", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "da9f812a-5f82-4eb8-b42c-f58be9e1ad59"}, { new Terminator(DelimiterType.Comma), "5a4cd270-a7b0-4914-ab2a-0e17937d72ce"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2ca84969-59a0-4f6e-9a29-c771f5540416") },
		{ "1caa9bbf-9279-442a-9fc0-26297d62e89b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "1caa9bbf-9279-442a-9fc0-26297d62e89b") },
		{ "ccdb46a7-5133-4d62-bfd3-00a2593312f2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "ccdb46a7-5133-4d62-bfd3-00a2593312f2") },
		{ "f887e062-3db6-4e36-9d96-7a26300d807c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "f887e062-3db6-4e36-9d96-7a26300d807c") },
		{ "644fc401-94d3-470d-a388-a646ce973dc0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "644fc401-94d3-470d-a388-a646ce973dc0") },
		{ "da9f812a-5f82-4eb8-b42c-f58be9e1ad59", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "da9f812a-5f82-4eb8-b42c-f58be9e1ad59") },
	};

    private GeneratedGrammarParser()
    {
        foreach(GeneratedTransformer transformer in s_transformers.Values)
        {
            transformer.ConstructShiftTable(s_transformers);
        }
    }

    private static GeneratedGrammarParser s_instance = new GeneratedGrammarParser();

    public static GeneratedGrammarParser Instance => s_instance;

	public ITransformer BeginTransformer => s_transformers["90611b1a-2bce-4802-bf73-921489b4be5a"];
	public NonTerminator Begin => new NonTerminator(NonTerminatorType.StartNonTerminator);
}
